@@ -515,10 +515,20 @@ void MainWindow::lookupTextChanged() {
 	keyText = entryText;
 
 	if (curMod) {
-		curMod->SetKey(keyText.c_str());
+		SWKey *key = curMod->CreateKey();
+		VerseKey *vkey = SWDYNAMIC_CAST(VerseKey, key);
+		key->Persist(1);
+		if (vkey) {
+			vkey->Headings(1);
+			vkey->AutoNormalize(0);
+		}
+		*key = keyText.c_str();
+		curMod->setKey(*key);
 		curMod->Display();
 		sprintf(tmpBuf, "%s (%s)", curMod->KeyText(), curMod->Name());
 		gtk_label_set(GTK_LABEL(statusbar1), tmpBuf);
+		curMod->setKey(keyText.c_str());
+		delete key;
 	}
 }
 
