@@ -14,7 +14,7 @@ __fastcall TForm1::TForm1(TComponent* Owner)
 //---------------------------------------------------------------------------
 void __fastcall TForm1::Button1Click(TObject *Sender)
 {
-		   webster->SetKey(Edit1->Text.c_str());
+		   webster->setKey(Edit1->Text.c_str());
            Memo1->Text = webster->operator char*();
 
 }
