@@ -15,7 +15,7 @@ __fastcall TAboutBox::TAboutBox(TComponent* AOwner) : TForm(AOwner) {
 //--------------------------------------------------------------------- 
 void __fastcall TAboutBox::FormShow(TObject *Sender) {
 	int i;
-	static char *modtypes[] = {"Biblical Texts", "Commentaries", "Lexicons / Dictionaries"};
+	static char *modtypes[] = {"Biblical Texts", "Commentaries", "Lexicons / Dictionaries", "Generic Books"};
 
 	string newtext, tmptext;
 	ModMap::iterator it;
@@ -26,7 +26,7 @@ void __fastcall TAboutBox::FormShow(TObject *Sender) {
 	newtext  = "{\\rtf1\\ansi{\\fonttbl{\\f4\\froman\\fcharset0\\fprq2 Times New Roman;}}{\\colortbl;\\red0\\green0\\blue255;\\red0\\green200\\blue50;}";
 	newtext += "\\pard\\qc\\cf2\\nowidctlpar{\\fs30\\b Installed Modules } \\par \\pard \\nowidctlpar \\cf0 ";
 
-	for (i = 0; i < 3; i++) {
+	for (i = 0; i < 4; i++) {
 		newtext += "\\par {\\fs28\\b ";
 		newtext += modtypes[i];
 		newtext += " }\\par \\par ";
@@ -59,7 +59,7 @@ void __fastcall TAboutBox::FormShow(TObject *Sender) {
 	newtext += "sword-patches@crosswire.org (please include unified diffs if possible (diff -u)) \\par\\par ";
 	newtext += "To be on our mailing list: \\par ";
 	newtext += "sword-list-info@crosswire.org \\par\\par ";
-	newtext += "This software is provided free for the study of God and His Word.  You DO NOT NEED TO license or pay for this software.  Please: copy it freely and distribute it to athiests in Russia :), post it on your favorite FTP site, write your own modules and features for it, include it on your lastest freeware CDROM, incorporate all the cool utility classes into a product of your own, write a tract module for the program and sneak it onto all of your co-workers' computers and blame it on a virus, make fun of your pastor for spending $400 dollars on a similar package, give it to your pastor who can't figure out how to use his $400 dollar package :) \\par\\par ";
+	newtext += "This software is provided free for the study of God and His Word.  You DO NOT NEED TO license or pay for this software.  Please: copy it freely and distribute it to atheists in Russia :), post it on your favorite FTP site, write your own modules and features for it, include it on your lastest freeware CDROM, incorporate all the cool utility classes into a product of your own, write a tract module for the program and sneak it onto all of your co-workers' computers and blame it on a virus, make fun of your pastor for spending $400 dollars on a similar package, give it to your pastor who can't figure out how to use his $400 dollar package :) \\par\\par ";
 	newtext += "OK, if you still feel the need, you can help our organization out at: \\par\\par ";
 	newtext += "CrossWire Software & Bible Society \\par ";
 	newtext += "P. O. Box 2528 \\par ";
@@ -75,7 +75,7 @@ void __fastcall TAboutBox::FormShow(TObject *Sender) {
 	newtext += "Roland Nygren; Bayu Gunawan; Bill Kincaid; Mark Fuller; Larry Pierce; Franklin Bratcher; ";
 	newtext += "Gregory Hall; Luis Cortes; Steve Hiner; Kristof Petr; Paul Gear and OpenBible; Chris Bitmead (go Scheme!); ";
 	newtext += "Brook Humphrey; Torsten Uhlmann, Joachim Ansorg, Darwin Gregory, Martin Gruner and the BibleTime Team; ";
-	newtext += "Darren DeMeulenaere; Terry Biggs and the GnomeSword Team; Daniel Glassey; David Trotz";
+	newtext += "Darren DeMeulenaere; Terry Biggs and the GnomeSword Team; Daniel Glassey; David Trotz Jr.; Karl-Heinz Troyer and BibleWorkshop";
 	newtext += "\\par\\par ";
 	newtext += "{\\i And the list goes on...} \\par \\par ";
 	newtext += "{\\fs24 \\par }}";
@@ -90,3 +90,33 @@ void __fastcall TAboutBox::FormShow(TObject *Sender) {
 
 
 
+void __fastcall TAboutBox::ProgramIconMouseDown(TObject *Sender,
+	 TMouseButton Button, TShiftState Shift, int X, int Y)
+{
+	if ((Shift.Contains(ssCtrl)) && (!Shift.Contains(ssAlt)) && (Button == mbRight)) {
+		TMemoryStream *RTFStream = new TMemoryStream();
+		string newtext = "{\\rtf1\\ansi{\\fonttbl{\\f4\\froman\\fcharset0\\fprq2 Times New Roman;}}{\\colortbl;\\red0\\green0\\blue255;\\red0\\green200\\blue50;}";
+		newtext += "\\fs20 mainmgr->config: \\par\\par ";
+
+		SectionMap::iterator section;
+		ConfigEntMap::iterator entry;
+
+		for (section = Form1->mainmgr->config->Sections.begin(); section != Form1->mainmgr->config->Sections.end(); section++) {
+			newtext += "["; newtext += section->first.c_str(); newtext += "] \\par ";
+			for (entry = (*section).second.begin(); entry != (*section).second.end(); entry++) {
+				newtext += entry->first.c_str(); newtext += "="; newtext += entry->second.c_str(); newtext += "\\par ";
+			}
+			newtext += "\\par ";
+		}
+
+
+		newtext += "{\\fs24 \\par }}";
+		RTFStream->Clear();
+		RTFStream->WriteBuffer(newtext.c_str(), newtext.length());
+		RTFStream->Position = 0;
+		CreditAbout->Lines->LoadFromStream(RTFStream);
+		delete RTFStream;
+	}
+}
+//---------------------------------------------------------------------------
+
