@@ -19,8 +19,8 @@ class TModVisForm : public TForm
 __published:	// IDE-managed Components
 	TPanel *Panel2;
 	TPanel *Panel1;
-	TBitBtn *BitBtn1;
-	TBitBtn *BitBtn2;
+	TBitBtn *OkBtn;
+	TBitBtn *CancelBtn;
 	TListView *modList;
 	void __fastcall FormShow(TObject *Sender);
 	void __fastcall FormClose(TObject *Sender, TCloseAction &Action);
