@@ -13,9 +13,10 @@ BibleCSMGR::BibleCSMGR(TModInstFrm *iModInstFrm) : SWMgr(0, 0, false, new Markup
 #ifdef _ICU_
 //        arshaping = new UTF8arShaping();
 	bidireorder = new UTF8BiDiReorder();
-	   transliterator = new UTF8Transliterator();
+//	   transliterator = new UTF8Transliterator();
 #endif
 	ModInstFrm = iModInstFrm;
+	userPrefs = 0;
 	Load();
 
 	OSVERSIONINFO osvi;
@@ -33,9 +34,13 @@ BibleCSMGR::~BibleCSMGR()
 //                delete arshaping;
 	   if (bidireorder)
 			 delete bidireorder;
-	   if (transliterator)
-			 delete transliterator;
+//	   if (transliterator)
+//			 delete transliterator;
 #endif
+	if (userPrefs) {
+		userPrefs->Save();
+		delete userPrefs;
+	}
 }
 
 
@@ -53,10 +58,11 @@ void BibleCSMGR::AddRenderFilters(SWModule *module, ConfigEntMap &section)
 //                }
 			 if (platformID == WIN9X || (strnicmp(lang.c_str(), "he", 2) && strnicmp(lang.c_str(), "ar", 2))) {
 				    module->AddRenderFilter(bidireorder);
-#endif
+
 			 }
-        }
-        SWMgr::AddRenderFilters(module, section);
+#endif
+	   }
+	   SWMgr::AddRenderFilters(module, section);
 }
 
 
@@ -65,7 +71,7 @@ char BibleCSMGR::AddModToConfig(int conffd, const char *fname)
 	SWConfig modconf(fname);
 	SectionMap::iterator section;
 	AnsiString abouttext = "";
-	bool logflag;
+	int logflag;
 	TMemoryStream *RTFStream = new TMemoryStream();
 	char retval;
 
@@ -83,10 +89,10 @@ char BibleCSMGR::AddModToConfig(int conffd, const char *fname)
 
 	ModInstFrm->ShowModal();
 
-	logflag = SWLog::systemlog->log;
-	SWLog::systemlog->log = false;
+	logflag = SWLog::systemlog->getLogLevel();
+	SWLog::systemlog->setLogLevel(0);
 	retval = SWMgr::AddModToConfig(conffd, fname);
-	SWLog::systemlog->log = logflag;
+	SWLog::systemlog->setLogLevel(logflag);
 
 	return retval;
 }
@@ -94,19 +100,31 @@ char BibleCSMGR::AddModToConfig(int conffd, const char *fname)
 signed char BibleCSMGR::Load () {
 	signed char retval = SWMgr::Load();
 #ifdef _ICU_
-	optionFilters.insert(FilterMap::value_type("UTF8Transliterator", transliterator));
-	   options.push_back(transliterator->getOptionName());
+//	optionFilters.insert(FilterMap::value_type("UTF8Transliterator", transliterator));
+//	options.push_back(transliterator->getOptionName());
 #endif
-        return retval;
+	userPrefs = new SWConfig("./userprefs.conf");
+	applyUserPrefs();
+	return retval;
 };
 
+void BibleCSMGR::applyUserPrefs() {
+	(*config) += (*userPrefs);
+}
+
 void BibleCSMGR::AddGlobalOptions (SWModule * module, ConfigEntMap & section,
 							ConfigEntMap::iterator start,
 							ConfigEntMap::iterator end) {
 
 	   SWMgr::AddGlobalOptions(module, section, start, end);
 #ifdef _ICU_
-	   module->AddOptionFilter(transliterator);
+//	   module->AddOptionFilter(transliterator);
 #endif
 };
 
+/*	maybe force a section for each module and set a per module userConfig. "But not like this.  Not like this."
+void BibleCSMGR::AddLocalOptions(SWModule *module, ConfigEntMap &section, ConfigEntMap::iterator start, ConfigEntMap::iterator end)
+{
+	userPrefs[module->Name()]["Font"];
+}
+*/
