@@ -12,19 +12,22 @@ class BibleCSMGR : public SWMgr {
 //	SWFilter *arshaping;
 	SWFilter *bidireorder;
         SWFilter *transliterator;
-        char platformID;
+	   char platformID;
+	SWConfig *userPrefs;
 
 protected:
 	virtual char AddModToConfig(int conffd, const char *fname);
 	virtual void AddRenderFilters(SWModule *module, ConfigEntMap &section);
-        virtual signed char Load ();
-        virtual void AddGlobalOptions (SWModule * module, ConfigEntMap & section,
-                                        ConfigEntMap::iterator start,
-                                        ConfigEntMap::iterator end);
+	   virtual signed char Load ();
+	   virtual void AddGlobalOptions (SWModule * module, ConfigEntMap & section,
+								ConfigEntMap::iterator start,
+								ConfigEntMap::iterator end);
 
 public:
 	BibleCSMGR(TModInstFrm *iModInstFrm);
 	virtual ~BibleCSMGR();
+	SWConfig &getUserPrefs() { return *userPrefs; }
+	void applyUserPrefs();
 };
 
 #endif
