@@ -5,26 +5,32 @@
 #include <stdio.h>
 #include "editentryfrm.h"
 #include <swdisprtf.h>
+#include "rxricheditx.h"
 
 const float RulerAdj = 4.0/3.0;
 const int GutterWid = 6;
 //----------------------------------------------------------------------------
 #pragma resource "*.dfm"
-TEditEntry *EditEntry;
+TEditEntryForm *EditEntryForm;
 //----------------------------------------------------------------------------
-__fastcall TEditEntry::TEditEntry(TComponent *Owner) : TForm(Owner) {
+__fastcall TEditEntryForm::TEditEntryForm(TComponent *Owner) : TForm(Owner) {
 	ResultBuf = 0;
+	RichEdit1 = new TRxRichEditX(this);
+
+	RichEdit1->Parent = pnlRichEdit;
+	RichEdit1->Align = alClient;
+	RichEdit1->ScrollBars = ssVertical;
 }
 
 
-__fastcall TEditEntry::~TEditEntry() {
+__fastcall TEditEntryForm::~TEditEntryForm() {
 	if (ResultBuf)
 		delete [] ResultBuf;
 }
 
 
 //----------------------------------------------------------------------------
-void __fastcall TEditEntry::SelectionChange(TObject */*Sender*/) {
+void __fastcall TEditEntryForm::SelectionChange(TObject */*Sender*/) {
 	char sizebuf[6];
 
 	try {
@@ -59,12 +65,12 @@ void __fastcall TEditEntry::SelectionChange(TObject */*Sender*/) {
 
 
 //----------------------------------------------------------------------------
-TTextAttributes *__fastcall TEditEntry::CurrText(void)
+TRxTextAttributes *__fastcall TEditEntryForm::CurrText(void)
 {
     return RichEdit1->SelAttributes;
 }
 //----------------------------------------------------------------------------
-void __fastcall TEditEntry::CheckFileSave(void)
+void __fastcall TEditEntryForm::CheckFileSave(void)
 {
 	if ( RichEdit1->Modified ) {
 		switch(MessageBox(Handle, "Save Changes?","Modify Comment",MB_YESNOCANCEL | MB_ICONQUESTION)) {
@@ -80,7 +86,7 @@ void __fastcall TEditEntry::CheckFileSave(void)
 }
 
 
-void __fastcall TEditEntry::SetupRuler(void)
+void __fastcall TEditEntryForm::SetupRuler(void)
 {    int iCtr = 1;
 	char sTmp[201];
 	while (iCtr < 200) {
@@ -92,52 +98,52 @@ void __fastcall TEditEntry::SetupRuler(void)
 	Ruler->Caption = (AnsiString)sTmp;
 }
 //----------------------------------------------------------------------------
-void __fastcall TEditEntry::SetEditRect(void)
+void __fastcall TEditEntryForm::SetEditRect(void)
 {    TRect Rct = Rect(GutterWid, 0, RichEdit1->ClientWidth-GutterWid,
 						 ClientHeight);
 	SendMessage(RichEdit1->Handle, EM_SETRECT, 0, long(&Rct));
 }
 //----------------------------------------------------------------------------
-void __fastcall TEditEntry::FormCreate(TObject* /*Sender*/)
+void __fastcall TEditEntryForm::FormCreate(TObject* /*Sender*/)
 {    Application->OnHint = &ShowHint;
 	SetupRuler();
 }
 //----------------------------------------------------------------------------
-void __fastcall TEditEntry::ShowHint(TObject* /*Sender*/)
+void __fastcall TEditEntryForm::ShowHint(TObject* /*Sender*/)
 {    StatusBar->SimpleText = Application->Hint;
 }
 //----------------------------------------------------------------------------
-void __fastcall TEditEntry::EditUndoClick(TObject* /*Sender*/)
+void __fastcall TEditEntryForm::EditUndoClick(TObject* /*Sender*/)
 {    if ( RichEdit1->HandleAllocated() )
 	   SendMessage(RichEdit1->Handle, EM_UNDO, 0, 0);
 }
 //----------------------------------------------------------------------------
-void __fastcall TEditEntry::EditCutClick(TObject* /*Sender*/)
+void __fastcall TEditEntryForm::EditCutClick(TObject* /*Sender*/)
 {    RichEdit1->CutToClipboard();
 }
 //----------------------------------------------------------------------------
-void __fastcall TEditEntry::EditCopyClick(TObject* /*Sender*/)
+void __fastcall TEditEntryForm::EditCopyClick(TObject* /*Sender*/)
 {    RichEdit1->CopyToClipboard();
 }
 //----------------------------------------------------------------------------
-void __fastcall TEditEntry::EditPasteClick(TObject* /*Sender*/)
+void __fastcall TEditEntryForm::EditPasteClick(TObject* /*Sender*/)
 {    RichEdit1->PasteFromClipboard();
 }
 //----------------------------------------------------------------------------
-void __fastcall TEditEntry::RulerResize(TObject* /*Sender*/)
+void __fastcall TEditEntryForm::RulerResize(TObject* /*Sender*/)
 {     RulerLine->Width = (int)Ruler->ClientWidth - (RulerLine->Left*2);
 }
 //----------------------------------------------------------------------------
-void __fastcall TEditEntry::FormResize(TObject* Sender)
+void __fastcall TEditEntryForm::FormResize(TObject* Sender)
 {    SetEditRect();
 	SelectionChange(Sender);
 }
 //----------------------------------------------------------------------------
-void __fastcall TEditEntry::FormPaint(TObject* /*Sender*/)
+void __fastcall TEditEntryForm::FormPaint(TObject* /*Sender*/)
 {    SetEditRect();
 }
 //----------------------------------------------------------------------------
-void __fastcall TEditEntry::BoldButtonClick(TObject* /*Sender*/)
+void __fastcall TEditEntryForm::BoldButtonClick(TObject* /*Sender*/)
 {    if ( !FUpdating )
 	{  if ( BoldButton->Down )
 		 CurrText()->Style = CurrText()->Style << fsBold;
@@ -146,7 +152,7 @@ void __fastcall TEditEntry::BoldButtonClick(TObject* /*Sender*/)
 	}
 }
 //----------------------------------------------------------------------------
-void __fastcall TEditEntry::ItalicButtonClick(TObject* /*Sender*/)
+void __fastcall TEditEntryForm::ItalicButtonClick(TObject* /*Sender*/)
 {    if ( !FUpdating )
 	{
 	   if ( ItalicButton->Down )
@@ -156,7 +162,7 @@ void __fastcall TEditEntry::ItalicButtonClick(TObject* /*Sender*/)
 	}
 }
 //----------------------------------------------------------------------------
-void __fastcall TEditEntry::UnderlineButtonClick(TObject* /*Sender*/)
+void __fastcall TEditEntryForm::UnderlineButtonClick(TObject* /*Sender*/)
 {
 	if ( !FUpdating ) {
 		if ( UnderlineButton->Down )
@@ -166,7 +172,7 @@ void __fastcall TEditEntry::UnderlineButtonClick(TObject* /*Sender*/)
 }
 
 
-void __fastcall TEditEntry::FontSizeChange(TObject* /*Sender*/)
+void __fastcall TEditEntryForm::FontSizeChange(TObject* /*Sender*/)
 {
 	int fontsize = atoi(FontSize->Text.c_str());
 
@@ -184,7 +190,7 @@ void __fastcall TEditEntry::FontSizeChange(TObject* /*Sender*/)
 }
 
 
-void __fastcall TEditEntry::AlignClick(TObject* Sender)
+void __fastcall TEditEntryForm::AlignClick(TObject* Sender)
 {
 	if ( !FUpdating ) {
 		TControl *oAliBtn = (TControl*)(Sender);
@@ -192,12 +198,12 @@ void __fastcall TEditEntry::AlignClick(TObject* Sender)
 	}
 }
 //----------------------------------------------------------------------------
-void __fastcall TEditEntry::BulletsButtonClick(TObject* /*Sender*/)
+void __fastcall TEditEntryForm::BulletsButtonClick(TObject* /*Sender*/)
 {    if ( !FUpdating )
 	   RichEdit1->Paragraph->Numbering = (TNumberingStyle)BulletsButton->Down;
 }
 //----------------------------------------------------------------------------
-void __fastcall TEditEntry::FormCloseQuery(TObject* /*Sender*/,
+void __fastcall TEditEntryForm::FormCloseQuery(TObject* /*Sender*/,
 	bool & CanClose)
 {    try {
 	  CheckFileSave();
@@ -213,7 +219,7 @@ void __fastcall TEditEntry::FormCloseQuery(TObject* /*Sender*/,
 //***************************
 
 //----------------------------------------------------------------------------
-void __fastcall TEditEntry::RulerItemMouseDown(TObject * Sender,
+void __fastcall TEditEntryForm::RulerItemMouseDown(TObject * Sender,
 	TMouseButton Button, TShiftState Shift, int X, int Y)
 {    TLabel * oTmpLabel = (TLabel *)Sender;
 	FDragOfs = oTmpLabel->Width / 2;
@@ -221,7 +227,7 @@ void __fastcall TEditEntry::RulerItemMouseDown(TObject * Sender,
 	FDragging = True;
 }
 //----------------------------------------------------------------------------
-void __fastcall TEditEntry::RulerItemMouseMove(TObject *Sender, TShiftState Shift, int X, int /*Y*/) {
+void __fastcall TEditEntryForm::RulerItemMouseMove(TObject *Sender, TShiftState Shift, int X, int /*Y*/) {
     if (FDragging) {
 	   TLabel *oTmpLabel = (TLabel *)Sender;
 	   oTmpLabel->Left = oTmpLabel->Left+X-FDragOfs;
@@ -229,14 +235,14 @@ void __fastcall TEditEntry::RulerItemMouseMove(TObject *Sender, TShiftState Shif
 	}
 }
 //----------------------------------------------------------------------------
-void __fastcall TEditEntry::FirstIndMouseUp(TObject *Sender, TMouseButton
+void __fastcall TEditEntryForm::FirstIndMouseUp(TObject *Sender, TMouseButton
 	Button, TShiftState Shift, int X, int Y)
 {    FDragging = False;
 	RichEdit1->Paragraph->FirstIndent = int((FirstInd->Left+FDragOfs-GutterWid) / RulerAdj);
 	LeftIndMouseUp(Sender, Button, Shift, X, Y);
 }
 //----------------------------------------------------------------------------
-void __fastcall TEditEntry::LeftIndMouseUp(TObject *Sender, TMouseButton
+void __fastcall TEditEntryForm::LeftIndMouseUp(TObject *Sender, TMouseButton
 	 /*Button*/, TShiftState /*Shift*/, int /*X*/,	int /*Y*/)
 {    FDragging = False;
 	RichEdit1->Paragraph->LeftIndent = int((LeftInd->Left+FDragOfs-GutterWid)/
@@ -244,7 +250,7 @@ void __fastcall TEditEntry::LeftIndMouseUp(TObject *Sender, TMouseButton
 	SelectionChange(Sender);
 }
 //----------------------------------------------------------------------------
-void __fastcall TEditEntry::RightIndMouseUp(TObject *Sender, TMouseButton
+void __fastcall TEditEntryForm::RightIndMouseUp(TObject *Sender, TMouseButton
 	 /*Button*/, TShiftState /*Shift*/, int /*X*/,	int /*Y*/)
 {    FDragging = False;
 	RichEdit1->Paragraph->RightIndent =
@@ -253,7 +259,7 @@ void __fastcall TEditEntry::RightIndMouseUp(TObject *Sender, TMouseButton
 	SelectionChange(Sender);
 }
 //----------------------------------------------------------------------------
-void __fastcall TEditEntry::FormActivate(TObject *Sender)
+void __fastcall TEditEntryForm::FormActivate(TObject *Sender)
 {
 	System::AnsiString newtext, tmptext;
 
@@ -263,9 +269,9 @@ void __fastcall TEditEntry::FormActivate(TObject *Sender)
 		Module->Error(); // clear error;
 		newtext = newtext + "\\pard \\nowidctlpar \\cf0 ";
 		(const char *)*Module;	// force key to snap to entry before pulling out the text of the key
-		tmptext = (const char *)*Module;
+		tmptext = Module->getRawEntry();
 	
-		newtext = newtext + RTFDisplay->RTFVersePre + " " + tmptext + RTFDisplay->RTFVersePost;
+		newtext = newtext + RTFDisplay->RTFVersePre + tmptext + RTFDisplay->RTFVersePost;
 		newtext = newtext + RTFDisplay->RTFTrailer;
 		RTFStream->Clear();
 		RTFStream->WriteBuffer(newtext.c_str(), newtext.Length());
@@ -281,7 +287,7 @@ void __fastcall TEditEntry::FormActivate(TObject *Sender)
 }
 //---------------------------------------------------------------------
 
-void TEditEntry::ExtractRTF()
+void TEditEntryForm::ExtractRTF()
 {
 	System::AnsiString newtext, tmptext;
 	TMemoryStream *RTFStream = new TMemoryStream();
@@ -298,8 +304,9 @@ void TEditEntry::ExtractRTF()
 	char *tbl = strstr(tmpbuf, "colortbl");
 	if (!tbl)
 		tbl = strstr(tmpbuf, "fonttbl");
-	if (tbl) {    
+	if (tbl) {
 		strtok(tbl, "}");
+//  		strtok(NULL, "}");
 		datastart = strtok(NULL, "");
 		ResultBuf = new char [ strlen(datastart) + 2 ];
 		ResultBuf[0] = '{';
@@ -321,9 +328,19 @@ void TEditEntry::ExtractRTF()
                               }
                          }
                     }
-               }
-          }
-     }
+				if (ResultBuf[i+1] == 'c') {
+					if (ResultBuf[i+2] == 'f') {
+						if (isdigit(ResultBuf[i+3])) {
+							ResultBuf[i+3] = '7';
+							if (isdigit(ResultBuf[i+4])) {
+								memmove(&ResultBuf[i+4], &ResultBuf[i+5], strlen(&ResultBuf[i+4]));
+							}
+						}
+					}
+				}
+			}
+		}
+	}
 }
 
 
