@@ -8,10 +8,8 @@
 #include <stdarg.h>
 //---------------------------------------------------------------------------
  
-SWWinLog::SWWinLog(HWND iparent)
-{
+SWWinLog::SWWinLog(HWND iparent) : SWLog() {
 	parent = iparent;
-	log = true;
 }
 
  
@@ -20,7 +18,7 @@ void SWWinLog::LogWarning(char *fmt, ...)
 	char msg[2048];
 	va_list argptr;
 
-	if (log) {
+	if (logLevel >= 2) {
 		va_start(argptr, fmt);
 		vsprintf(msg, fmt, argptr);
 		va_end(argptr);
@@ -35,7 +33,7 @@ void SWWinLog::LogError(char *fmt, ...)
 	char msg[2048];
 	va_list argptr;
 
-	if (log) {
+	if (logLevel) {
 		va_start(argptr, fmt);
 		vsprintf(msg, fmt, argptr);
 		va_end(argptr);
@@ -50,7 +48,7 @@ void SWWinLog::LogTimedInformation(char *fmt, ...)
 	char msg[2048];
 	va_list argptr;
 
-	if (log) {
+	if (logLevel >= 4) {
 		va_start(argptr, fmt);
 		vsprintf(msg, fmt, argptr);
 		va_end(argptr);
@@ -66,7 +64,7 @@ void SWWinLog::LogInformation(char *fmt, ...)
 	char msg[2048];
 	va_list argptr;
 
-	if (log) {
+	if (logLevel >= 3) {
 		va_start(argptr, fmt);
 		vsprintf(msg, fmt, argptr);
 		va_end(argptr);
