@@ -1,5 +1,5 @@
 #include <stdio.h>
-#include <iostream.h>
+#include <iostream>
 #include <stdlib.h>
 #include <swmgr.h>
 
@@ -25,27 +25,27 @@ int main(int argc, char **argv)
 
 	target = (*it).second;
 
-	target->SetKey(argv[2]);
+	target->setKey(argv[2]);
 
 	(const char *)*target;		// force an entry lookup to resolve key so we
 						// get the idxbuf entry for the key
-	cout << (const char *)(SWKey &)*target << ":\n";
-	cout << target->StripText();
-	cout << "\n";
-	cout << "==========================\n";
-	cout << "Entry Attributes:\n\n";
+	std::cout << (const char *)(SWKey &)*target << ":\n";
+	std::cout << target->StripText();
+	std::cout << "\n";
+	std::cout << "==========================\n";
+	std::cout << "Entry Attributes:\n\n";
 	AttributeTypeList::iterator i1;
 	AttributeList::iterator i2;
 	AttributeValue::iterator i3;
 	for (i1 = target->getEntryAttributes().begin(); i1 != target->getEntryAttributes().end(); i1++) {
-		cout << "[ " << i1->first << " ]\n";
+		std::cout << "[ " << i1->first << " ]\n";
 		for (i2 = i1->second.begin(); i2 != i1->second.end(); i2++) {
-			cout << "\t[ " << i2->first << " ]\n";
+			std::cout << "\t[ " << i2->first << " ]\n";
 			for (i3 = i2->second.begin(); i3 != i2->second.end(); i3++) {
-				cout << "\t\t" << i3->first << " = " << i3->second << "\n";
+				std::cout << "\t\t" << i3->first << " = " << i3->second << "\n";
 			}
 		}
 	}
-	cout << endl;
+	std::cout << std::endl;
 	return 0;
 }
