@@ -3,7 +3,7 @@
  *			pointing to actual text desired.  Uses standard
  *			files:	ot and nt using indexs ??.bks ??.cps ??.vss
  *
- * $Id: hrefcom.h,v 1.5 2002/02/19 01:20:35 scribe Exp $
+ * $Id: hrefcom.h,v 1.6 2002/07/28 01:48:38 scribe Exp $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -29,17 +29,21 @@
 
 #include <defs.h>
 
-class SWDLLEXPORT HREFCom:public RawVerse, public SWCom
-{
-  char *prefix;
+class SWDLLEXPORT HREFCom:public RawVerse, public SWCom {
+	char *prefix;
 
 public:
-  
-    
-    HREFCom (const char *ipath, const char *prefix, const char *iname =
-	     0, const char *idesc = 0, SWDisplay * idisp = 0);
-    virtual ~ HREFCom ();
-  virtual char *getRawEntry ();
+
+
+	HREFCom(const char *ipath, const char *prefix, const char *iname = 0,
+			const char *idesc = 0, SWDisplay * idisp = 0);
+	virtual ~HREFCom();
+	virtual char *getRawEntry();
+
+	// OPERATORS -----------------------------------------------------------------
+	
+	SWMODULE_OPERATORS
+
 };
 
 
