@@ -4,7 +4,7 @@
  *				(e.g. verse, word,
  *				place, etc.)
  *
- * $Id: listkey.h,v 1.13 2001/08/09 10:39:51 scribe Exp $
+ * $Id: listkey.h,v 1.15 2002/09/11 07:04:20 scribe Exp $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -104,12 +104,14 @@ public:
 
 	virtual char Traversable () { return 1; }
 	virtual long Index () const { return arraypos; }
+	virtual const char *getRangeText() const;
 
 	/**
 	* Returns the index for the new one given as as parameter.
 	* The first parameter is the new index.
 	*/
 	virtual long Index (long index) { SetToElement (index); return Index (); }
+	virtual const char *getText() const;
 
 	SWKEY_OPERATORS
 	ListKey & operator =(const ListKey &key) { copyFrom(key); return *this; }
