@@ -2,7 +2,7 @@
  *  swld.h   - code for base class 'SWLD'.  SWLD is the basis for all
  *				types of Lexicon and Dictionary modules (hence the 'LD').
  *
- * $Id: swld.h,v 1.10 2001/12/18 04:47:40 chrislit Exp $
+ * $Id: swld.h,v 1.12 2002/07/28 01:48:38 scribe Exp $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -31,30 +31,38 @@
   /** the basis for all types of Lexicon and
   * Dictionary modules (hence the 'LD').
   */
-class SWDLLEXPORT SWLD:public SWModule
-{
+class SWDLLEXPORT SWLD : public SWModule {
 protected:
-  char *entkeytxt;
+	char *entkeytxt;
 public:
-  /** Initializes data for instance of SWLD
-  *
-  * @param imodname Internal name for module
-  * @param imoddesc Name to display to user for module
-  * @param idisp Display object to use for displaying
-  */
-  SWLD (const char *imodname = 0, const char *imoddesc = 0, SWDisplay * idisp = 0, SWTextEncoding encoding = ENC_UNKNOWN, SWTextDirection dir = DIRECTION_LTR, SWTextMarkup markup = FMT_UNKNOWN, const char* ilang = 0);
-  virtual ~ SWLD ();
-  virtual SWKey *CreateKey ()
-  {
-    return new StrKey ();
-  }
-  /** Sets/gets module KeyText, getting from saved text if key is persistent
-  *
-  * @param ikeytext value which to set keytext;
-  *  [0] - only get
-  * @return pointer to keytext
-  */
-  virtual const char *KeyText (const char *ikeytext);
+	/** Initializes data for instance of SWLD
+	*
+	* @param imodname Internal name for module
+	* @param imoddesc Name to display to user for module
+	* @param idisp Display object to use for displaying
+	*/
+	SWLD(const char *imodname = 0, const char *imoddesc = 0,
+			SWDisplay * idisp = 0, SWTextEncoding encoding = ENC_UNKNOWN,
+			SWTextDirection dir = DIRECTION_LTR,
+			SWTextMarkup markup = FMT_UNKNOWN, const char* ilang = 0);
+	
+	virtual ~SWLD();
+	virtual SWKey *CreateKey() { return new StrKey(); }
+
+	/** Sets/gets module KeyText, getting from saved text if key is persistent
+	*
+	* @param ikeytext value which to set keytext;
+	*  [0] - only get
+	* @return pointer to keytext
+	*/
+	virtual const char *KeyText(const char *ikeytext = 0);
+	virtual void setPosition(SW_POSITION pos);
+
+
+	// OPERATORS -----------------------------------------------------------------
+	
+	SWMODULE_OPERATORS
+
 };
 
 
