@@ -2,7 +2,7 @@
  *  swlocale.h   - definition of Class SWLocale used for retrieval
  *				of locale lookups
  *
- * $Id: swlocale.h,v 1.6 2001/03/23 22:15:14 jansorg Exp $
+ * $Id: swlocale.h,v 1.7 2002/07/28 01:48:38 scribe Exp $
  *
  * Copyright 2000 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -41,33 +41,33 @@ typedef map < string, string, less < string > >LookupMap;
 * get the name of the Language using @see getname of this class.
 * Another functions useful for frontend developers is @see getDescription.
 */
-class SWDLLEXPORT SWLocale
-{
-  LookupMap lookupTable;
-  SWConfig *localeSource;
-  char *name;
-  char *description;
-  struct abbrev *bookAbbrevs;
-  char *BMAX;
-  struct sbook **books;
+class SWDLLEXPORT SWLocale {
+	LookupMap lookupTable;
+	SWConfig *localeSource;
+	char *name;
+	char *description;
+	struct abbrev *bookAbbrevs;
+	char *BMAX;
+	struct sbook **books;
 
 public:
-  SWLocale (const char *ifilename);
-  virtual ~ SWLocale ();
+	SWLocale(const char *ifilename);
+	virtual ~SWLocale();
 
-  /**
-  * This function is used to get the name of the languages which this object is handling.
-  * @return The name of the managed language. A possible example is "de".
-  */
-  virtual const char *getName ();
-  /**
-  * @return The description. A possible example is "German".
-  */
-  virtual const char *getDescription ();
-  virtual const char *translate (const char *text);
-  virtual SWLocale & operator += (SWLocale & addFrom);
-  virtual const struct abbrev *getBookAbbrevs ();
-  virtual void getBooks (char **iBMAX, struct sbook ***ibooks);
+	/**
+	* This function is used to get the name of the languages which this object is handling.
+	* @return The name of the managed language. A possible example is "de".
+	*/
+	virtual const char *getName();
+	/**
+	* @return The description. A possible example is "German".
+	*/
+	virtual const char *getDescription();
+	virtual const char *translate(const char *text);
+	virtual void augment(SWLocale &addFrom);
+	virtual SWLocale & operator +=(SWLocale &addFrom) { augment(addFrom); return *this; }
+	virtual const struct abbrev *getBookAbbrevs();
+	virtual void getBooks(char **iBMAX, struct sbook ***ibooks);
 };
 
 #endif
