@@ -1,7 +1,7 @@
 /******************************************************************************
  *  swversion.h   - definition of class SWVersion used to compare version info
  *
- * $Id: swversion.h,v 1.3 2002/01/06 22:26:23 chrislit Exp $
+ * $Id: swversion.h,v 1.5 2002/09/28 12:14:50 joachim Exp $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -20,7 +20,7 @@
  */
 
 #ifndef SWORDVER
-#define SWORDVER "1.5.3"
+#define SWORDVER "1.5.4"
 #endif
 
 #ifndef SWVERSION_H
@@ -32,7 +32,8 @@ class SWVersion {
 	
 	SWVersion(const char *version = "0.0");
 	int compare(const SWVersion &vi) const;
-	operator const char *() const;
+	const char *getText() const;
+	operator const char *() const { return getText(); }
 	bool operator>(const SWVersion &vi) const {return (compare(vi) > 0);}
 	bool operator<(const SWVersion &vi) const {return (compare(vi) < 0);}
 	bool operator==(const SWVersion &vi) const {return (compare(vi) == 0);}
