@@ -1,7 +1,7 @@
 /******************************************************************************
  *	versekey.h - code for class 'versekey'- a standard Biblical verse key
  *
- * $Id: versekey.h,v 1.24 2002/03/22 05:26:34 scribe Exp $
+ * $Id: versekey.h,v 1.27 2002/08/27 22:52:36 scribe Exp $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -367,7 +367,10 @@ public:
 	*/
 	virtual long Index(long iindex);
 
+	virtual const char *getOSISRef() const;
+
 	virtual ListKey ParseVerseList(const char *buf, const char *defaultKey = "Genesis 1:1", bool expandRange = false);
+	virtual const char *getRangeText() const;
 	/** Compares another	SWKey object
 	*
 	* @param ikey key to compare with this one
@@ -391,6 +394,11 @@ public:
 	virtual void setLocale(const char *name);
 	virtual const char *getLocale() const { return locale; }
 
+
+
+	// OPERATORS --------------------------------------------------------------------
+
+
 	SWKEY_OPERATORS
 
 	virtual SWKey & operator = (const VerseKey & ikey) { copyFrom(ikey); return *this; }
