@@ -2,7 +2,7 @@
  *  ztext.h   - code for class 'zText'- a module that reads compressed text
  *				files: ot and nt using indexs ??.vss
  *
- * $Id: ztext.h,v 1.22 2002/03/16 04:18:34 scribe Exp $
+ * $Id: ztext.h,v 1.25 2002/09/25 21:22:03 scribe Exp $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -35,36 +35,45 @@
 */
 class SWDLLEXPORT zText:public zVerse, public SWText {
      VerseKey *lastWriteKey;
-     bool sameBlock (VerseKey * lastWriteKey, VerseKey * key);
+     bool sameBlock(VerseKey * lastWriteKey, VerseKey * key);
 	int blockType;
 public:
   
     
-	zText(const char *ipath, const char *iname = 0, const char *idesc =
-	   0, int blockType = CHAPTERBLOCKS, SWCompress * icomp =
-	   0, SWDisplay * idisp = 0, SWTextEncoding encoding = ENC_UNKNOWN, SWTextDirection dir = DIRECTION_LTR, SWTextMarkup markup = FMT_UNKNOWN,
-           const char* ilang = 0);
-	virtual ~zText ();
+	zText(const char *ipath, const char *iname = 0, const char *idesc = 0,
+			int blockType = CHAPTERBLOCKS, SWCompress * icomp = 0,
+			SWDisplay * idisp = 0, SWTextEncoding encoding = ENC_UNKNOWN,
+			SWTextDirection dir = DIRECTION_LTR,
+			SWTextMarkup markup = FMT_UNKNOWN, const char* ilang = 0);
+
+	virtual ~zText();
  	virtual char *getRawEntry();
 
-     virtual SWModule & operator += (int increment);
-     virtual SWModule & operator -= (int decrement) { return this->operator += (-decrement); }
+	virtual void increment(int steps = 1);
+	virtual void decrement(int steps = 1) { increment(-steps); }
 
   // write interface ----------------------------
-	virtual bool isWritable () { return ((idxfp[0]->getFd() > 0) && ((idxfp[0]->mode & O_RDWR) == O_RDWR)); }
-	static char createModule (const char *path, int blockBound) {
-		return zVerse::createModule (path, blockBound);
+	virtual bool isWritable() { return ((idxfp[0]->getFd() > 0) && ((idxfp[0]->mode & O_RDWR) == O_RDWR)); }
+	static char createModule(const char *path, int blockBound) {
+		return zVerse::createModule(path, blockBound);
 	}
 
-     virtual SWModule & setentry (const char *inbuf, long len);	// Modify current module entry
-     virtual SWModule & operator << (const char *inbuf);	// Modify current module entry
-     virtual SWModule & operator << (const SWKey * linkKey);	// Link current module entry to other module entry
-     virtual void deleteEntry ();	// Delete current module entry
+     virtual void setEntry(const char *inbuf, long len = -1);	// Modify current module entry
+     virtual void linkEntry(const SWKey *linkKey);	// Link current module entry to other module entry
+     virtual void deleteEntry();	// Delete current module entry
   // end write interface ------------------------
   
+	virtual void rawZFilter(char *buf, long size, char direction = 0) { rawFilter(buf, size, (SWKey *)(long)direction); }// hack, use key as direction for enciphering
+
 	// swcacher interface ----------------------
 	virtual void flush() { flushCache(); }
 	// end swcacher interface ----------------------
+
+
+	// OPERATORS -----------------------------------------------------------------
+	
+	SWMODULE_OPERATORS
+
 };
 
 #endif
