@@ -1,5 +1,5 @@
 /******************************************************************************
- *  rawverse.h   - code for class 'RawVerse'- a module that reads raw text
+ *  rawverse.h   - code for class 'zVerse'- a module that reads raw text
  *			files:  ot and nt using indexs ??.bks ??.cps ??.vss
  *			and provides lookup and parsing functions based on
  *			class VerseKey
@@ -19,17 +19,16 @@ class SWDLLEXPORT zVerse {
 	SWCompress *compressor;
 
 protected:
-	static int instance;		// number of instantiated RawVerse objects or derivitives
+	static int instance;		// number of instantiated zVerse objects or derivitives
 
 	FileDesc *idxfp[2];
 	FileDesc *textfp[2];
 	FileDesc *compfp[2];
 	char *path;
-	void preptext (char *buf);
-	void settext (char testmt, long idxoff, const char *buf, long len = 0);
-	void linkentry (char testmt, long destidxoff, long srcidxoff);
-	void flushCache ();
-	//RawVerse();
+	void preptext(char *buf);
+	void settext(char testmt, long idxoff, const char *buf, long len = 0);
+	void linkentry(char testmt, long destidxoff, long srcidxoff);
+	void flushCache();
 	char *cacheBuf;
 	char cacheTestament;
 	long cacheBufIdx;
@@ -45,11 +44,12 @@ public:
 	char nl;
 
 
-	zVerse (const char *ipath, int fileMode = O_RDONLY, int blockType = CHAPTERBLOCKS, SWCompress * icomp = 0);
-	virtual ~ zVerse ();
-	void findoffset (char testmt, long idxoff, long *start, unsigned short *end);
-	void swgettext (char testmt, long start, unsigned short size, char *buf);
-	static char createModule (const char *path, int blockBound);
+	zVerse(const char *ipath, int fileMode = O_RDONLY, int blockType = CHAPTERBLOCKS, SWCompress * icomp = 0);
+	virtual ~zVerse();
+	void findoffset(char testmt, long idxoff, long *start, unsigned short *end);
+	void zreadtext(char testmt, long start, unsigned short size, char *buf);
+	virtual void rawZFilter(char *buf, long size, char direction = 0) {}
+	static char createModule(const char *path, int blockBound);
 };
 
 
