@@ -3,10 +3,12 @@
  *		  types of displays (e.g. raw textout, curses, xwindow, etc.)
  */
 
-#include <iostream.h>
+#include <iostream>
 #include <swmodule.h>
 #include <swdisp.h>
 
+static const char *classes[] = {"SWDisplay", "SWObject", 0};
+SWClass SWDisplay::classdef(classes);
 
 /******************************************************************************
  * SWDisplay::Display - casts a module to a character pointer and displays it to
@@ -20,6 +22,6 @@
 
 char SWDisplay::Display(SWModule &imodule)
 {
-	cout << (const char *)imodule;
+	std::cout << (const char *)imodule;
 	return 0;
 }
