@@ -3,7 +3,7 @@
 #include <stdarg.h>
 #include <stdio.h>
 #ifndef _MSC_VER
-#include <iostream.h>
+#include <iostream>
 #endif
 #include "swlog.h"
 //---------------------------------------------------------------------------
@@ -28,14 +28,14 @@ void SWLog::LogWarning(char *fmt, ...)
 	char msg[2048];
 	va_list argptr;
 
-	if (log) {
+	if (logLevel >= 2) {
 		va_start(argptr, fmt);
 		vsprintf(msg, fmt, argptr);
 		va_end(argptr);
 
 #ifndef _MSC_VER
-		cerr << msg;
-		cerr << "\n";
+		std::cerr << msg;
+		std::cerr << std::endl;
 #endif
 	}
 }
@@ -46,14 +46,14 @@ void SWLog::LogError(char *fmt, ...)
 	char msg[2048];
 	va_list argptr;
 
-	if (log) {
+	if (logLevel) {
 		va_start(argptr, fmt);
 		vsprintf(msg, fmt, argptr);
 		va_end(argptr);
 
 #ifndef _MSC_VER
-		cerr << msg;
-		cerr << "\n";
+		std::cerr << msg;
+		std::cerr << std::endl;
 #endif
 	}
 }
@@ -64,14 +64,14 @@ void SWLog::LogTimedInformation(char *fmt, ...)
 	char msg[2048];
 	va_list argptr;
 
-	if (log) {
+	if (logLevel >= 4) {
 		va_start(argptr, fmt);
 		vsprintf(msg, fmt, argptr);
 		va_end(argptr);
 
 #ifndef _MSC_VER
-		cout << msg;
-		cout << "\n";
+		std::cout << msg;
+		std::cout << std::endl;
 #endif
 	}
 }
@@ -82,14 +82,14 @@ void SWLog::LogInformation(char *fmt, ...)
 	char msg[2048];
 	va_list argptr;
 
-	if (log) {
+	if (logLevel >= 3) {
 		va_start(argptr, fmt);
 		vsprintf(msg, fmt, argptr);
 		va_end(argptr);
 
 #ifndef _MSC_VER
-		cout << msg;
-		cout << "\n";
+		std::cout << msg;
+		std::cout << std::endl;
 #endif
 	}
 } 
