@@ -145,8 +145,9 @@ void ListKey::increment(int step) {
 	Error();		// clear error
 	for(; step && !Error(); step--) {
 		if (arraypos < arraycnt) {
-			(*(array[arraypos]))++;
-			if (array[arraypos]->Error()) {
+			if (array[arraypos]->isBoundSet())
+				(*(array[arraypos]))++;
+			if ((array[arraypos]->Error()) || (!array[arraypos]->isBoundSet())) {
 				SetToElement(arraypos+1);
 			}
 			else *this = (const char *)(*array[arraypos]);
@@ -168,8 +169,9 @@ void ListKey::decrement(int step) {
 	Error();		// clear error
 	for(; step && !Error(); step--) {
 		if (arraypos > -1) {
-			(*(array[arraypos]))--;
-			if (array[arraypos]->Error()) {
+			if (array[arraypos]->isBoundSet())
+				(*(array[arraypos]))--;
+			if ((array[arraypos]->Error()) || (!array[arraypos]->isBoundSet())) {
 				SetToElement(arraypos-1, BOTTOM);
 			}
 			else *this = (const char *)(*array[arraypos]);
@@ -213,7 +215,8 @@ char ListKey::SetToElement(int ielement, SW_POSITION pos) {
 	}
 	
 	if (arraycnt) {
-		(*array[arraypos]) = pos;
+		if (array[arraypos]->isBoundSet())
+			(*array[arraypos]) = pos;
 		*this = (const char *)(*array[arraypos]);
 	}
 	else *this = "";
@@ -231,11 +234,12 @@ char ListKey::SetToElement(int ielement, SW_POSITION pos) {
  */
 
 SWKey *ListKey::GetElement(int pos) {
-	if (pos >=0) {
-		if (pos >=arraycnt)
-			error = KEYERR_OUTOFBOUNDS;
-	}
-	else pos = arraypos;
+	if (pos < 0)
+		pos = arraypos;
+		
+	if (pos >=arraycnt)
+		error = KEYERR_OUTOFBOUNDS;
+
 	return (error) ? 0:array[pos];
 }
 	
@@ -254,3 +258,35 @@ void ListKey::Remove() {
 		SetToElement((arraypos)?arraypos-1:0);
 	}
 }
+
+
+/******************************************************************************
+ * ListKey::getRangeText - returns parsable range text for this key
+ */
+
+const char *ListKey::getRangeText() const {
+	char *buf = new char[(arraycnt + 1) * 255];
+	buf[0] = 0;
+	for (int i = 0; i < arraycnt; i++) {
+		strcat(buf, array[i]->getRangeText());
+		if (i < arraycnt-1)
+			strcat(buf, "; ");
+	}
+	stdstr(&rangeText, buf);
+	delete [] buf;
+	return rangeText;
+}
+
+
+/******************************************************************************
+ * ListKey::getText - returns text key if (const char *) cast is requested
+ */
+
+const char *ListKey::getText() const {
+	int pos = arraypos;
+	SWKey *key = (pos >= arraycnt) ? 0:array[pos];
+	return (key) ? key->getText() : keytext;
+}
+
+
+
