@@ -19,26 +19,30 @@ SWClass SWKey::classdef(classes);
 
 SWKey::SWKey(const char *ikey)
 {
-	index   = 0;
-	persist = 0;
-	keytext = 0;
-	error   = 0;
+	index     = 0;
+	persist   = 0;
+	keytext   = 0;
+	rangeText = 0;
+	error     = 0;
 	stdstr(&keytext, ikey);
 	init();
 }
 
 SWKey::SWKey(SWKey const &k)
 {
-	index   = k.index;
-	persist = k.persist;
-	keytext = 0;
-	error = k.error;
+	index     = k.index;
+	persist   = k.persist;
+	userData  = k.userData;
+	keytext   = 0;
+	rangeText = 0;
+	error     = k.error;
 	stdstr(&keytext, k.keytext);
 	init();
 }
 
 void SWKey::init() {
 	myclass = &classdef;
+	boundSet = false;
 }
 
 SWKey *SWKey::clone() const
@@ -53,12 +57,14 @@ SWKey *SWKey::clone() const
 SWKey::~SWKey() {
 	if (keytext)
 		delete [] keytext;
+	if (rangeText)
+		delete [] rangeText;
 }
 
 
 /******************************************************************************
  * SWKey::Persist - Gets whether this object itself persists within a
- *			module that it was used to SetKey or just a copy.
+ *			module that it was used to setKey or just a copy.
  *			(1 - persists in module; 0 - a copy is attempted
  *
  * RET:	value of persist
@@ -72,7 +78,7 @@ char SWKey::Persist() const
 
 /******************************************************************************
  * SWKey::Persist - Set/gets whether this object itself persists within a
- *			module that it was used to SetKey or just a copy.
+ *			module that it was used to setKey or just a copy.
  *			(1 - persists in module; 0 - a copy is attempted
  *
  * ENT:	ipersist - value which to set persist
@@ -129,7 +135,7 @@ void SWKey::copyFrom(const SWKey &ikey) {
 
 
 /******************************************************************************
- * SWKey::getText - returns text key if (char *) cast is requested
+ * SWKey::getText - returns text key if (const char *) cast is requested
  */
 
 const char *SWKey::getText() const {
@@ -137,6 +143,16 @@ const char *SWKey::getText() const {
 }
 
 
+/******************************************************************************
+ * SWKey::getRangeText - returns parsable range text for this key
+ */
+
+const char *SWKey::getRangeText() const {
+	stdstr(&rangeText, keytext);
+	return rangeText;
+}
+
+
 /******************************************************************************
  * SWKey::compare	- Compares another VerseKey object
  *
