@@ -1,7 +1,7 @@
 /******************************************************************************
  *  versekey.h - code for class 'versekey'- a standard Biblical verse key
  *
- * $Id: treekey.cpp,v 1.1 2002/01/24 08:55:27 scribe Exp $
+ * $Id: treekey.cpp,v 1.2 2002/04/15 21:26:44 scribe Exp $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -25,3 +25,6 @@
 static const char *classes[] = {"TreeKey", "SWKey", "SWObject", 0};
 SWClass TreeKey::classdef(classes);
 
+void TreeKey::init() {
+	myclass = &classdef;
+}
