@@ -1,7 +1,7 @@
 /******************************************************************************
  *  versekey.h - code for class 'versekey'- a standard Biblical verse key
  *
- * $Id: treekeyidx.cpp,v 1.5 2002/03/18 20:52:45 scribe Exp $
+ * $Id: treekeyidx.cpp,v 1.8 2002/09/11 07:04:20 scribe Exp $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -33,12 +33,13 @@
 #endif
 
 using namespace std;
-static const char *classes[] = {"TreeKeyIdx", "TreeKey", "SWKey", "SWObject", 0};
 static const char nl = '\n';
+static const char *classes[] = {"TreeKeyIdx", "TreeKey", "SWKey", "SWObject", 0};
 SWClass TreeKeyIdx::classdef(classes);
 
 
 TreeKeyIdx::TreeKeyIdx(const TreeKeyIdx &ikey) : currentNode() {
+	init();
 	path = 0;
 	idxfd = 0;
 	datfd = 0;
@@ -48,6 +49,7 @@ TreeKeyIdx::TreeKeyIdx(const TreeKeyIdx &ikey) : currentNode() {
 TreeKeyIdx::TreeKeyIdx(const char *idxPath, int fileMode) : currentNode() {
 	char buf[127];
 
+	init();
 	path = 0;
 	stdstr(&path, idxPath);
 
@@ -75,6 +77,11 @@ TreeKeyIdx::TreeKeyIdx(const char *idxPath, int fileMode) : currentNode() {
 }
 
 
+void TreeKeyIdx::init() {
+	myclass = &classdef;
+}
+
+
 TreeKeyIdx::~TreeKeyIdx () {
 	if (path)
 		delete [] path;
@@ -395,6 +402,8 @@ void TreeKeyIdx::saveTreeNodeOffsets(TreeNode *node) {
 
 void TreeKeyIdx::copyFrom(const TreeKeyIdx &ikey) {
 
+	SWKey::copyFrom(ikey);
+
 	currentNode.offset = ikey.currentNode.offset;
 	currentNode.parent = ikey.currentNode.parent;
 	currentNode.next = ikey.currentNode.next;
@@ -579,3 +588,10 @@ TreeKeyIdx::TreeNode::~TreeNode() {
 	if (userData)
 		delete [] userData;
 }
+
+
+SWKey *TreeKeyIdx::clone() const
+{
+	return new TreeKeyIdx(*this);
+}
+
