@@ -55,6 +55,7 @@ void VerseKey::init() {
 	headings = 0;		// default display headings option is false
 	upperBound = 0;
 	lowerBound = 0;
+	boundSet = false;
 	testament = 0;
 	book = 0;
 	chapter = 0;
@@ -94,7 +95,7 @@ VerseKey::VerseKey(const char *ikey) : SWKey(ikey)
 }
 
 
-VerseKey::VerseKey(VerseKey const &k) : SWKey(k.keytext)
+VerseKey::VerseKey(VerseKey const &k) : SWKey(k)
 {
 	init();
 	autonorm = k.autonorm;
@@ -103,8 +104,10 @@ VerseKey::VerseKey(VerseKey const &k) : SWKey(k.keytext)
 	book = k.Book();
 	chapter = k.Chapter();
 	verse = k.Verse();
-	LowerBound(k.LowerBound());
-	UpperBound(k.UpperBound());
+	if (k.isBoundSet()) {
+		LowerBound(k.LowerBound());
+		UpperBound(k.UpperBound());
+	}
 }
 
 
@@ -169,8 +172,12 @@ void VerseKey::setLocale(const char *name) {
 		localeCache.abbrevsCnt = abbrevsCnt;
 	}
 	stdstr(&(this->locale), localeCache.name);
-}
 
+	if (lowerBound)
+		LowerBound().setLocale(name);
+	if (upperBound) 
+		UpperBound().setLocale(name);
+}
 
 void VerseKey::setBooks(const char *iBMAX, struct sbook **ibooks) {
 	BMAX = iBMAX;
@@ -181,7 +188,7 @@ void VerseKey::setBooks(const char *iBMAX, struct sbook **ibooks) {
 void VerseKey::setBookAbbrevs(const struct abbrev *bookAbbrevs, unsigned int size) {
 	abbrevs = bookAbbrevs;
 	if (!size) {
-		for (abbrevsCnt = 1; *abbrevs[abbrevsCnt].ab; abbrevsCnt++) {
+		for (abbrevsCnt = 0; *abbrevs[abbrevsCnt].ab; abbrevsCnt++) {
 			/*
 			if (strcmp(abbrevs[abbrevsCnt-1].ab, abbrevs[abbrevsCnt].ab) > 0) {
 				fprintf(stderr, "ERROR: book abbreviation (canon.h or locale) misordered at entry: %s\n", abbrevs[abbrevsCnt].ab);
@@ -193,7 +200,7 @@ void VerseKey::setBookAbbrevs(const struct abbrev *bookAbbrevs, unsigned int siz
             for (int i = 0; i < BMAX[t]; i++) {
                 int bn = getBookAbbrev(books[t][i].name);
                 if ((bn-1)%39 != i) {
-                    SWLog::systemlog->LogError("Book: %s does not have a matching toupper abbrevs entry! book number returned was: %d", books[t][i].name, bn);
+				SWLog::systemlog->LogError("Book: %s does not have a matching toupper abbrevs entry! book number returned was: %d", books[t][i].name, bn);
                 }
             }
         }
@@ -237,7 +244,7 @@ char VerseKey::parse()
 	chapter   = 1;
 	verse     = 1;
 
-	error     = 0;
+	int error = 0;
 
 	if (keytext) {
 		ListKey tmpListKey = VerseKey::ParseVerseList(keytext);
@@ -256,12 +263,12 @@ char VerseKey::parse()
 				sscanf(&keytext[strlen(books[testament-1][book-1].name)], "%d:%d", &chapter, &verse);
 			}
 			else	error = 1;
-		}
+		} else error = 1;
 	}
 	Normalize(1);
 	freshtext();
 
-	return error;
+	return (this->error) ? this->error : (this->error = error);
 }
 
 
@@ -306,35 +313,39 @@ void VerseKey::freshtext() const
 
 int VerseKey::getBookAbbrev(const char *iabbr)
 {
-    int loop, diff, abLen, min, max, target, retVal = -1;
+	int loop, diff, abLen, min, max, target, retVal = -1;
 
-    char *abbr = 0;
+	char *abbr = 0;
 
-	stdstr(&abbr, iabbr);
-	strstrip(abbr);
-	abLen = strlen(abbr);
-	for (loop = 0; loop < abLen; loop++)
-		abbr[loop] = SW_toupper(abbr[loop]);
+	for (int i = 0; i < 2; i++) {
+		stdstr(&abbr, iabbr);
+		strstrip(abbr);
+		if (!i)
+			toupperstr(abbr);
+		abLen = strlen(abbr);
 
-	if (abLen) {
-		min = 0;
-//		max = abbrevsCnt - 1;
-		max = abbrevsCnt;
-		while(1) {
-			target = min + ((max - min) / 2);
-			diff = strncmp(abbr, abbrevs[target].ab, abLen);
-			if ((!diff)||(target >= max)||(target <= min))
-				break;
-			if (diff > 0)
-				min = target;
-			else	max = target;
+		if (abLen) {
+			min = 0;
+//			max = abbrevsCnt - 1;
+			max 	= abbrevsCnt;
+			while(1) {
+				target = min + ((max - min) / 2);
+				diff = strncmp(abbr, abbrevs[target].ab, abLen);
+				if ((!diff)||(target >= max)||(target <= min))
+					break;
+				if (diff > 0)
+					min = target;
+				else	max = target;
+			}
+			for (; target > 0; target--) {
+				if (strncmp(abbr, abbrevs[target-1].ab, abLen))
+					break;
+			}
+				
+			retVal = (!diff) ? abbrevs[target].book : -1;
 		}
-		for (; target > 0; target--) {
-			if (strncmp(abbr, abbrevs[target-1].ab, abLen))
-				break;
-		}
-			
-		retVal = (!diff) ? abbrevs[target].book : -1;
+		if (retVal > 0)
+			break;
 	}
 	delete [] abbr;
 	return retVal;
@@ -359,8 +370,8 @@ int VerseKey::getBookAbbrev(const char *iabbr)
 ListKey VerseKey::ParseVerseList(const char *buf, const char *defaultKey, bool expandRange) {
 	SWKey textkey;
 
-	char book[255];
-	char number[255];
+	char book[2048];
+	char number[2048];
 	int tobook = 0;
 	int tonumber = 0;
 	int chap = -1, verse = -1;
@@ -379,6 +390,7 @@ ListKey VerseKey::ParseVerseList(const char *buf, const char *defaultKey, bool e
 
 	curkey.AutoNormalize(0);
 	tmpListKey << tmpDefaultKey;
+	tmpListKey.GetElement()->userData = (void *)buf;
 	
 	while (*buf) {
 		switch (*buf) {
@@ -440,7 +452,8 @@ ListKey VerseKey::ParseVerseList(const char *buf, const char *defaultKey, bool e
 						chap = VerseKey(tmpListKey).Chapter();
                               *book = 0;
                          }
-                    }
+				}
+				
 				bookno = getBookAbbrev(book);
 			}
 			if (((bookno > -1) || (!*book)) && ((*book) || (chap >= 0) || (verse >= 0))) {
@@ -485,6 +498,7 @@ ListKey VerseKey::ParseVerseList(const char *buf, const char *defaultKey, bool e
 					newElement.LowerBound(curkey);
 					newElement.setPosition(TOP);
 					tmpListKey << newElement;
+					tmpListKey.GetElement()->userData = (void *)buf;
 				}
 				else {
 					if (!dash) { 	// if last separator was not a dash just add
@@ -498,8 +512,12 @@ ListKey VerseKey::ParseVerseList(const char *buf, const char *defaultKey, bool e
 							newElement.UpperBound(curkey);
 							newElement = TOP;
 							tmpListKey << newElement;
+							tmpListKey.GetElement()->userData = (void *)buf;
+						}
+						else {
+							tmpListKey << (const SWKey &)(const SWKey)(const char *)curkey;
+							tmpListKey.GetElement()->userData = (void *)buf;
 						}
-						else tmpListKey << (const SWKey &)(const SWKey)(const char *)curkey;
 					}
 					else	if (expandRange) {
 						VerseKey *newElement = SWDYNAMIC_CAST(VerseKey, tmpListKey.GetElement());
@@ -510,6 +528,7 @@ ListKey VerseKey::ParseVerseList(const char *buf, const char *defaultKey, bool e
 								curkey = MAXVERSE;
 							newElement->UpperBound(curkey);
 							*newElement = TOP;
+							tmpListKey.GetElement()->userData = (void *)buf;
 						}
 					}
 				}
@@ -550,7 +569,7 @@ ListKey VerseKey::ParseVerseList(const char *buf, const char *defaultKey, bool e
 				}
 			}
 			if (chap == -1)
-				book[tobook++] = SW_toupper(*buf);
+				book[tobook++] = *buf;
 		}
 		buf++;
 	}
@@ -582,15 +601,15 @@ ListKey VerseKey::ParseVerseList(const char *buf, const char *defaultKey, bool e
 		}
 
 		for (loop = strlen(book) - 1; loop+1; loop--) {
-          	if (book[loop] == ' ') {
-               	if (isroman(&book[loop+1])) {
-                    	if (verse == -1) {
-                         	verse = chap;
-                              chap = from_rom(&book[loop+1]);
-                              book[loop] = 0;
-                         }
-                    }
-               	break;
+			if (book[loop] == ' ') {
+				if (isroman(&book[loop+1])) {
+					if (verse == -1) {
+						verse = chap;
+						chap = from_rom(&book[loop+1]);
+						book[loop] = 0;
+					}
+				}
+				break;
 			}
           }
                
@@ -646,6 +665,7 @@ ListKey VerseKey::ParseVerseList(const char *buf, const char *defaultKey, bool e
 			newElement.LowerBound(curkey);
 			newElement = TOP;
 			tmpListKey << newElement;
+			tmpListKey.GetElement()->userData = (void *)buf;
 		}
 		else {
 			if (!dash) { 	// if last separator was not a dash just add
@@ -659,8 +679,12 @@ ListKey VerseKey::ParseVerseList(const char *buf, const char *defaultKey, bool e
 					newElement.UpperBound(curkey);
 					newElement = TOP;
 					tmpListKey << newElement;
+					tmpListKey.GetElement()->userData = (void *)buf;
+				}
+				else {
+					tmpListKey << (const SWKey &)(const SWKey)(const char *)curkey;
+					tmpListKey.GetElement()->userData = (void *)buf;
 				}
-				else tmpListKey << (const SWKey &)(const SWKey)(const char *)curkey;
 			}
 			else if (expandRange) {
 				VerseKey *newElement = SWDYNAMIC_CAST(VerseKey, tmpListKey.GetElement());
@@ -671,6 +695,7 @@ ListKey VerseKey::ParseVerseList(const char *buf, const char *defaultKey, bool e
 						curkey = MAXVERSE;
 					newElement->UpperBound(curkey);
 					*newElement = TOP;
+					tmpListKey.GetElement()->userData = (void *)buf;
 				}
 			}
 		}
@@ -696,7 +721,8 @@ VerseKey &VerseKey::LowerBound(const char *lb)
 
 	(*lowerBound) = lb;
 	lowerBound->Normalize();
-
+	lowerBound->setLocale( this->getLocale() );
+	boundSet = true;
 	return (*lowerBound);
 }
 
@@ -715,6 +741,7 @@ VerseKey &VerseKey::UpperBound(const char *ub)
 	if (*upperBound < *lowerBound)
 		*upperBound = *lowerBound;
 	upperBound->Normalize();
+	upperBound->setLocale( this->getLocale() );
 
 // until we have a proper method to resolve max verse/chap use this kludge
 	int len = strlen(ub);
@@ -736,7 +763,7 @@ VerseKey &VerseKey::UpperBound(const char *ub)
 	
 
 // -- end kludge
-
+	boundSet = true;
 	return (*upperBound);
 }
 
@@ -799,6 +826,7 @@ void VerseKey::initBounds() const
 	upperBound->Book(BMAX[1]);
 	upperBound->Chapter(books[1][BMAX[1]-1].chapmax);
 	upperBound->Verse(books[1][BMAX[1]-1].versemax[upperBound->Chapter()-1]);
+	boundSet = false;
 }
 
 
@@ -1403,3 +1431,51 @@ int VerseKey::_compare(const VerseKey &ivkey)
 	keyval1 = (keyval1) ? ((keyval1 > 0) ? 1 : -1) /*keyval1/labs(keyval1)*/:0; // -1 | 0 | 1
 	return keyval1;
 }
+
+
+const char *VerseKey::getOSISRef() const {
+	static char buf[5][254];
+	static char loop = 0;
+
+	if (loop > 4)
+		loop = 0;
+
+	static char *osisotbooks[] = {
+			"Gen","Exod","Lev","Num","Deut","Josh","Judg","Ruth","1Sam","2Sam",
+			"1Kgs","2Kgs","1Chr","2Chr","Ezra","Neh","Esth","Job","Ps",
+			"Prov",		// added this.  Was not in OSIS spec
+			"Eccl",
+			"Song","Isa","Jer","Lam","Ezek","Dan","Hos","Joel","Amos","Obad",
+			"Jonah","Mic","Nah","Hab","Zeph","Hag","Zech","Mal","Bar","PrAzar",
+			"Bel","Sus","1Esd","2Esd","AddEsth","EpJer","Jdt","1Macc","2Macc","3Macc",
+			"4Macc","PrMan","Ps151","Sir","Tob","Wis"};
+	static char *osisntbooks[] = {
+			"Matt","Mark","Luke","John","Acts","Rom","1Cor","2Cor","Gal","Eph",
+			"Phil","Col","1Thess","2Thess","1Tim","2Tim","Titus","Phlm","Heb","Jas",
+			"1Pet","2Pet","1John","2John","3John","Jude","Rev"};
+	static char **osisbooks[] = { osisotbooks, osisntbooks };
+	if (Verse())
+		sprintf(buf[loop], "%s.%d.%d", osisbooks[Testament()-1][Book()-1], (int)Chapter(), (int)Verse());
+	else if (Chapter())
+		sprintf(buf[loop], "%s.%d", osisbooks[Testament()-1][Book()-1], (int)Chapter());
+	else if (Book())
+		sprintf(buf[loop], "%s", osisbooks[Testament()-1][Book()-1]);
+	else	sprintf(buf[loop], "");
+	return buf[loop++];
+}
+
+
+/******************************************************************************
+ * VerseKey::getRangeText - returns parsable range text for this key
+ */
+
+const char *VerseKey::getRangeText() const {
+	if (isBoundSet()) {
+		char buf[1023];
+		sprintf(buf, "%s-%s", (const char *)LowerBound(), (const char *)UpperBound());
+		stdstr(&rangeText, buf);
+	}
+	else stdstr(&rangeText, getText());
+	return rangeText;
+}
+
