@@ -2,7 +2,7 @@
  *  swmgr.cpp   - implementaion of class SWMgr used to interact with an install
  *				base of sword modules.
  *
- * $Id: swmgr.cpp,v 1.70 2002/03/22 05:26:34 scribe Exp $
+ * $Id: swmgr.cpp,v 1.79 2002/08/09 05:53:48 scribe Exp $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -32,7 +32,7 @@
 #endif
 #include <sys/stat.h>
 #ifndef _MSC_VER
-#include <iostream.h>
+#include <iostream>
 #endif
 #include <dirent.h>
 
@@ -70,8 +70,11 @@
 
 
 
-#ifdef ICU
+#ifdef _ICU_
 #include <utf8transliterator.h>
+bool SWMgr::isICU = true;
+#else
+bool SWMgr::isICU = false;
 #endif
 
 #ifndef EXCLUDEZLIB
@@ -156,13 +159,14 @@ void SWMgr::init() {
 	optionFilters.insert(FilterMap::value_type("GreekLexAttribs", tmpFilter));
 	cleanupFilters.push_back(tmpFilter);
 
-/* UTF8Transliterator needs to be handled differently because it should always available as an option, for all modules
-#ifdef ICU
-	tmpFilter = new UTF8Transliterator();
-	optionFilters.insert(FilterMap::value_type("UTF8Transliterator", tmpFilter));
-	cleanupFilters.push_back(tmpFilter);
+// UTF8Transliterator needs to be handled differently because it should always available as an option, for all modules
+#ifdef _ICU_
+	transliterator = new UTF8Transliterator();
+	optionFilters.insert(FilterMap::value_type("UTF8Transliterator", transliterator));
+	options.push_back(transliterator->getOptionName());
+	cleanupFilters.push_back(transliterator);
 #endif
-*/
+
 	gbfplain = new GBFPlain();
 	cleanupFilters.push_back(gbfplain);
 
@@ -263,9 +267,10 @@ SWMgr::~SWMgr() {
 }
 
 
-void SWMgr::findConfig(char *configType, char **prefixPath, char **configPath) {
+void SWMgr::findConfig(char *configType, char **prefixPath, char **configPath, list<string> *augPaths) {
 	string path;
 	ConfigEntMap::iterator entry;
+	ConfigEntMap::iterator lastEntry;
 
 	char *envsworddir = getenv ("SWORD_PATH");
 	char *envhomedir  = getenv ("HOME");
@@ -275,14 +280,14 @@ void SWMgr::findConfig(char *configType, char **prefixPath, char **configPath) {
 #ifndef _MSC_VER
 	// check working directory
 if (debug)
-	cerr << "Checking working directory for mods.conf...";
+	std::cerr << "Checking working directory for mods.conf...";
 #endif
 
 	if (FileMgr::existsFile(".", "mods.conf")) {
 
 #ifndef _MSC_VER
 if (debug)
-	cerr << "found\n";
+	std::cerr << "found\n";
 #endif
 
 		stdstr(prefixPath, "./");
@@ -292,14 +297,14 @@ if (debug)
 
 #ifndef _MSC_VER
 if (debug)
-	cerr << "\nChecking working directory for mods.d...";
+	std::cerr << "\nChecking working directory for mods.d...";
 #endif
 
 	if (FileMgr::existsDir(".", "mods.d")) {
 
 #ifndef _MSC_VER
 if (debug)
-	cerr << "found\n";
+	std::cerr << "found\n";
 #endif
 
 		stdstr(prefixPath, "./");
@@ -312,14 +317,14 @@ if (debug)
 	// check environment variable SWORD_PATH
 #ifndef _MSC_VER
 if (debug)
-	cerr << "\nChecking SWORD_PATH...";
+	std::cerr << "\nChecking SWORD_PATH...";
 #endif
 
 	if (envsworddir != NULL) {
 
 #ifndef _MSC_VER
 if (debug)
-	cerr << "found (" << envsworddir << ")\n";
+	std::cerr << "found (" << envsworddir << ")\n";
 #endif
 
 		path = envsworddir;
@@ -328,14 +333,14 @@ if (debug)
 
 #ifndef _MSC_VER
 if (debug)
-	cerr << "\nChecking $SWORD_PATH for mods.conf...";
+	std::cerr << "\nChecking $SWORD_PATH for mods.conf...";
 #endif
 
 		if (FileMgr::existsFile(path.c_str(), "mods.conf")) {
 
 #ifndef _MSC_VER
 if (debug)
-	cerr << "found\n";
+	std::cerr << "found\n";
 #endif
 
 			stdstr(prefixPath, path.c_str());
@@ -346,14 +351,14 @@ if (debug)
 
 #ifndef _MSC_VER
 if (debug)
-	cerr << "\nChecking $SWORD_PATH for mods.d...";
+	std::cerr << "\nChecking $SWORD_PATH for mods.d...";
 #endif
 
 		if (FileMgr::existsDir(path.c_str(), "mods.d")) {
 
 #ifndef _MSC_VER
 if (debug)
-	cerr << "found\n";
+	std::cerr << "found\n";
 #endif
 
 			stdstr(prefixPath, path.c_str());
@@ -369,7 +374,7 @@ if (debug)
 
 #ifndef _MSC_VER
 if (debug)
-	cerr << "\nParsing " << globalConfPath << "...";
+	std::cerr << "\nParsing " << globalConfPath << "...";
 #endif
 
 	char *globPaths = 0;
@@ -379,7 +384,7 @@ if (debug)
 
 	#ifndef _MSC_VER
 if (debug)
-	cerr << "\nChecking for " << gfp << "...";
+	std::cerr << "\nChecking for " << gfp << "...";
 #endif
 
 		if (FileMgr::existsFile(gfp))
@@ -390,7 +395,7 @@ if (debug)
 
 #ifndef _MSC_VER
 if (debug)
-	cerr << "found\n";
+	std::cerr << "found\n";
 #endif
 
 		SWConfig etcconf(gfp);
@@ -401,56 +406,66 @@ if (debug)
 
 #ifndef _MSC_VER
 if (debug)
-	cerr << "DataPath in " << gfp << " is set to: " << path;
+	std::cerr << "DataPath in " << gfp << " is set to: " << path;
 #endif
 
 #ifndef _MSC_VER
 if (debug)
-	cerr << "\nChecking for mods.conf in DataPath ";
+	std::cerr << "\nChecking for mods.conf in DataPath ";
 #endif
 			if (FileMgr::existsFile(path.c_str(), "mods.conf")) {
 
 #ifndef _MSC_VER
 if (debug)
-	cerr << "found\n";
+	std::cerr << "found\n";
 #endif
 
 				stdstr(prefixPath, path.c_str());
 				path += "mods.conf";
 				stdstr(configPath, path.c_str());
-				delete [] globPaths;
-				return;
+				*configType = 1;
 			}
 
 #ifndef _MSC_VER
 if (debug)
-	cerr << "\nChecking for mods.d in DataPath ";
+	std::cerr << "\nChecking for mods.d in DataPath ";
 #endif
 
 			if (FileMgr::existsDir(path.c_str(), "mods.d")) {
 
 #ifndef _MSC_VER
 if (debug)
-	cerr << "found\n";
+	std::cerr << "found\n";
 #endif
 
 				stdstr(prefixPath, path.c_str());
 				path += "mods.d";
 				stdstr(configPath, path.c_str());
 				*configType = 1;
-				delete [] globPaths;
-				return;
+			}
+		}
+		if (augPaths) {
+			augPaths->clear();
+			entry     = etcconf.Sections["Install"].lower_bound("AugmentPath");
+			lastEntry = etcconf.Sections["Install"].upper_bound("AugmentPath");
+			for (;entry != lastEntry; entry++) {
+				path = entry->second;
+				if ((entry->second.c_str()[strlen(entry->second.c_str())-1] != '\\') && (entry->second.c_str()[strlen(entry->second.c_str())-1] != '/'))
+					path += "/";
+				augPaths->push_back(path);
 			}
 		}
 	}
 
 	delete [] globPaths;
+	if (*configType)
+		return;
 
 	// check ~/.sword/
 
 #ifndef _MSC_VER
 if (debug)
-	cerr << "\nChecking home directory for ~/.sword/mods.conf" << path;
+	std::cerr << "\nChecking home directory for ~/.sword/mods.conf" << path;
 #endif
 
 	if (envhomedir != NULL) {
@@ -462,7 +477,7 @@ if (debug)
 
 #ifndef _MSC_VER
 if (debug)
-	cerr << " found\n";
+	std::cerr << " found\n";
 #endif
 
 			stdstr(prefixPath, path.c_str());
@@ -473,14 +488,14 @@ if (debug)
 
 #ifndef _MSC_VER
 if (debug)
-	cerr << "\nChecking home directory for ~/.sword/mods.d" << path;
+	std::cerr << "\nChecking home directory for ~/.sword/mods.d" << path;
 #endif
 
 		if (FileMgr::existsDir(path.c_str(), "mods.d")) {
 
 #ifndef _MSC_VER
 if (debug)
-	cerr << "found\n";
+	std::cerr << "found\n";
 #endif
 
 			stdstr(prefixPath, path.c_str());
@@ -526,6 +541,36 @@ void SWMgr::loadConfigDir(const char *ipath)
 }
 
 
+void SWMgr::augmentModules(const char *ipath) {
+	string path = ipath;
+	if ((ipath[strlen(ipath)-1] != '\\') && (ipath[strlen(ipath)-1] != '/'))
+		path += "/";
+	if (FileMgr::existsDir(path.c_str(), "mods.d")) {
+		char *savePrefixPath = 0;
+		char *saveConfigPath = 0;
+		SWConfig *saveConfig = 0;
+		stdstr(&savePrefixPath, prefixPath);
+		stdstr(&prefixPath, path.c_str());
+		path += "mods.d";
+		stdstr(&saveConfigPath, configPath);
+		stdstr(&configPath, path.c_str());
+		saveConfig = config;
+		config = myconfig = 0;
+		loadConfigDir(configPath);
+
+		CreateMods();
+
+		stdstr(&prefixPath, savePrefixPath);
+		delete []savePrefixPath;
+		stdstr(&configPath, saveConfigPath);
+		delete []saveConfigPath;
+		(*saveConfig) += *config;
+		homeConfig = myconfig;
+		config = myconfig = saveConfig;
+	}
+}
+
+
 /***********************************************************************
  * SWMgr::Load - loads actual modules
  *
@@ -538,7 +583,7 @@ signed char SWMgr::Load() {
 
 	if (!config) {	// If we weren't passed a config object at construction, find a config file
 		if (!configPath)	// If we weren't passed a config path at construction...
-			findConfig(&configType, &prefixPath, &configPath);
+			findConfig(&configType, &prefixPath, &configPath, &augPaths);
 		if (configPath) {
 			if (configType)
 				loadConfigDir(configPath);
@@ -565,37 +610,18 @@ signed char SWMgr::Load() {
 
 		CreateMods();
 
+		for (list<string>::iterator pathIt = augPaths.begin(); pathIt != augPaths.end(); pathIt++) {
+			augmentModules(pathIt->c_str());
+		}
 //	augment config with ~/.sword/mods.d if it exists ---------------------
-			char *envhomedir  = getenv ("HOME");
-			if (envhomedir != NULL && configType != 2) { // 2 = user only
-				string path = envhomedir;
-				if ((envhomedir[strlen(envhomedir)-1] != '\\') && (envhomedir[strlen(envhomedir)-1] != '/'))
-					path += "/";
-				path += ".sword/";
-				if (FileMgr::existsDir(path.c_str(), "mods.d")) {
-					char *savePrefixPath = 0;
-					char *saveConfigPath = 0;
-					SWConfig *saveConfig = 0;
-					stdstr(&savePrefixPath, prefixPath);
-					stdstr(&prefixPath, path.c_str());
-					path += "mods.d";
-					stdstr(&saveConfigPath, configPath);
-					stdstr(&configPath, path.c_str());
-					saveConfig = config;
-					config = myconfig = 0;
-					loadConfigDir(configPath);
-
-					CreateMods();
-
-					stdstr(&prefixPath, savePrefixPath);
-					delete []savePrefixPath;
-					stdstr(&configPath, saveConfigPath);
-					delete []saveConfigPath;
-					(*saveConfig) += *config;
-					homeConfig = myconfig;
-					config = myconfig = saveConfig;
-				}
-			}
+		char *envhomedir  = getenv ("HOME");
+		if (envhomedir != NULL && configType != 2) { // 2 = user only
+			string path = envhomedir;
+			if ((envhomedir[strlen(envhomedir)-1] != '\\') && (envhomedir[strlen(envhomedir)-1] != '/'))
+				path += "/";
+			path += ".sword/";
+			augmentModules(path.c_str());
+		}
 // -------------------------------------------------------------------------
 		if ( !Modules.size() ) // config exists, but no modules
 			ret = 1;
@@ -645,11 +671,12 @@ SWModule *SWMgr::CreateMod(string name, string driver, ConfigEntMap &section)
         else
                 markup = FMT_PLAIN;
 
-    	if (!stricmp(encoding.c_str(), "SCSU"))
-                enc = ENC_SCSU;
-        else if (!stricmp(encoding.c_str(), "UTF-8"))
-                enc = ENC_UTF8;
-        else enc = ENC_LATIN1;
+	if (!stricmp(encoding.c_str(), "SCSU"))
+		enc = ENC_SCSU;
+	else if (!stricmp(encoding.c_str(), "UTF-8")) {
+		enc = ENC_UTF8;
+	}
+	else enc = ENC_LATIN1;
 
 	if ((entry = section.find("Direction")) == section.end()) {
                 direction = DIRECTION_LTR;
@@ -769,6 +796,9 @@ void SWMgr::AddGlobalOptions(SWModule *module, ConfigEntMap &section, ConfigEntM
 	}
 	if (filterMgr)
 		filterMgr->AddGlobalOptions(module, section, start, end);
+#ifdef _ICU_
+	   module->AddOptionFilter(transliterator);
+#endif
 }
 
 
