@@ -49,7 +49,7 @@ RawFiles::~RawFiles()
 
 
 /******************************************************************************
- * RawFiles::operator char *	- Returns the correct verse when char * cast
+ * RawFiles::getRawEntry	- Returns the correct verse when char * cast
  *					is requested
  *
  * RET: string buffer with verse
@@ -81,7 +81,7 @@ char *RawFiles::getRawEntry() {
 	if (size) {
 		tmpbuf   = new char [ (size + 2) + strlen(path) + 5 ];
 		sprintf(tmpbuf,"%s/",path);
-		gettext(key->Testament(), start, (size + 2), tmpbuf+strlen(tmpbuf));
+		readtext(key->Testament(), start, (size + 2), tmpbuf+strlen(tmpbuf));
 		datafile = FileMgr::systemFileMgr.open(tmpbuf, O_RDONLY|O_BINARY);
 		delete [] tmpbuf;
 		if (datafile->getFd() > 0) {
@@ -90,7 +90,7 @@ char *RawFiles::getRawEntry() {
 			memset(entrybuf, 0, size * FILTERPAD);
 			lseek(datafile->getFd(), 0, SEEK_SET);
 			read(datafile->getFd(), entrybuf, size);
-			preptext(entrybuf);
+//			preptext(entrybuf);
 		}
 		else {
 			entrybuf = new char [2];
@@ -113,36 +113,31 @@ char *RawFiles::getRawEntry() {
 
 
 /******************************************************************************
- * RawFiles::operator << (char *)- Update the modules current key entry with
+ * RawFiles::setEntry(char *)- Update the modules current key entry with
  *				provided text
- *
- * RET: *this
  */
 
-SWModule &RawFiles::operator <<(const char *inbuf) {
+void RawFiles::setEntry(const char *inbuf, long len) {
 	FileDesc *datafile;
 	long  start;
 	unsigned short size;
 	char *tmpbuf;
 	VerseKey *key = 0;
 
-#ifndef _WIN32_WCE
+	len = (len<0)?strlen(inbuf):len;
 	try {
-#endif
 		key = SWDYNAMIC_CAST(VerseKey, this->key);
-#ifndef _WIN32_WCE
 	}
 	catch ( ... ) {}
-#endif
 	if (!key)
 		key = new VerseKey(this->key);
 
 	findoffset(key->Testament(), key->Index(), &start, &size);
 
 	if (size) {
-		tmpbuf   = new char [ (size + 2) + strlen(path) + 1 ];
+		tmpbuf   = new char [ (size + 3) + strlen(path) + 1 ];
 		sprintf(tmpbuf, "%s/", path);
-		gettext(key->Testament(), start, (size + 2), tmpbuf+strlen(tmpbuf));
+		readtext(key->Testament(), start, (size + 2), tmpbuf+strlen(tmpbuf));
 	}
 	else {
 		tmpbuf   = new char [ 16 + strlen(path) + 1 ];
@@ -152,39 +147,33 @@ SWModule &RawFiles::operator <<(const char *inbuf) {
 	datafile = FileMgr::systemFileMgr.open(tmpbuf, O_CREAT|O_WRONLY|O_BINARY|O_TRUNC);
 	delete [] tmpbuf;
 	if (datafile->getFd() > 0) {
-		write(datafile->getFd(), inbuf, strlen(inbuf));
+		write(datafile->getFd(), inbuf, len);
 	}
 	FileMgr::systemFileMgr.close(datafile);
 	
 	if (key != this->key)
 		delete key;
-
-	return *this;
 }
 
 
 /******************************************************************************
- * RawFiles::operator << (SWKey *)- Link the modules current key entry with
+ * RawFiles::linkEntry(SWKey *)- Link the modules current key entry with
  *				another module entry
  *
  * RET: *this
  */
 
-SWModule &RawFiles::operator <<(const SWKey *inkey) {
+void RawFiles::linkEntry(const SWKey *inkey) {
 
 	long  start;
 	unsigned short size;
 	char *tmpbuf;
 	const VerseKey *key = 0;
 
-#ifndef _WIN32_WCE
 	try {
-#endif
 		key = SWDYNAMIC_CAST(VerseKey, inkey);
-#ifndef _WIN32_WCE
 	}
 	catch ( ... ) {}
-#endif
 	if (!key)
 		key = new VerseKey(this->key);
 
@@ -192,20 +181,16 @@ SWModule &RawFiles::operator <<(const SWKey *inkey) {
 
 	if (size) {
 		tmpbuf   = new char [ size + 2];
-		gettext(key->Testament(), start, size + 2, tmpbuf);
+		readtext(key->Testament(), start, size + 2, tmpbuf);
 
 		if (key != inkey)
 			delete key;
 		key = 0;
 
-#ifndef _WIN32_WCE
 		try {
-#endif
 			key = SWDYNAMIC_CAST(VerseKey, inkey);
-#ifndef _WIN32_WCE
 		}
 		catch ( ... ) {}
-#endif
 		if (!key)
 			key = new VerseKey(this->key);
 		settext(key->Testament(), key->Index(), tmpbuf);
@@ -213,8 +198,6 @@ SWModule &RawFiles::operator <<(const SWKey *inkey) {
 	
 	if (key != inkey)
 		delete key;
-
-	return *this;
 }
 
 
