@@ -49,7 +49,7 @@ zCom::~zCom() {
 }
 
 /******************************************************************************
- * zCom::operator char *	- Returns the correct verse when char * cast
+ * zCom::getRawEntry	- Returns the correct verse when char * cast
  *					is requested
  *
  * RET: string buffer with verse
@@ -59,14 +59,10 @@ char *zCom::getRawEntry() {
 	unsigned short size = 0;
 	VerseKey *key = 0;
 
-#ifndef _WIN32_WCE
 	try {
-#endif
 		key = SWDYNAMIC_CAST(VerseKey, this->key);
-#ifndef _WIN32_WCE
 	}
 	catch ( ... ) {}
-#endif
 	// if we don't have a VerseKey * decendant, create our own
 	if (!key)
 		key = new VerseKey(this->key);
@@ -83,7 +79,7 @@ char *zCom::getRawEntry() {
 	}
 	*entrybuf = 0;
 
-	swgettext(key->Testament(), start, (size + 2), entrybuf);
+	zreadtext(key->Testament(), start, (size + 2), entrybuf);
 
 	rawFilter(entrybuf, size, key);
 
@@ -115,17 +111,13 @@ bool zCom::sameBlock(VerseKey *k1, VerseKey *k2) {
 	return true;
 }
 
-SWModule &zCom::setentry(const char *inbuf, long len) {
+void zCom::setEntry(const char *inbuf, long len) {
 	VerseKey *key = 0;
 	// see if we have a VerseKey * or decendant
-#ifndef _WIN32_WCE
 	try {
-#endif
 		key = SWDYNAMIC_CAST(VerseKey, this->key);
-#ifndef _WIN32_WCE
 	}
 	catch ( ... ) {}
-#endif
 	// if we don't have a VerseKey * decendant, create our own
 	if (!key)
 		key = new VerseKey(this->key);
@@ -145,41 +137,27 @@ SWModule &zCom::setentry(const char *inbuf, long len) {
 
 	if (this->key != key) // free our key if we created a VerseKey
 		delete key;
-
-	return *this;
-}
-
-SWModule &zCom::operator <<(const char *inbuf) {
-        return setentry(inbuf, 0);
 }
 
 
-SWModule &zCom::operator <<(const SWKey *inkey) {
+void zCom::linkEntry(const SWKey *inkey) {
 	VerseKey *destkey = 0;
 	const VerseKey *srckey = 0;
 	// see if we have a VerseKey * or decendant
-#ifndef _WIN32_WCE
 	try {
-#endif
 		destkey = SWDYNAMIC_CAST(VerseKey, this->key);
-#ifndef _WIN32_WCE
 	}
 	catch ( ... ) {}
-#endif
 	// if we don't have a VerseKey * decendant, create our own
 	if (!destkey)
 		destkey = new VerseKey(this->key);
 
 	// see if we have a VerseKey * or decendant
-#ifndef _WIN32_WCE
 	try {
-#endif
 		srckey = (const VerseKey *) SWDYNAMIC_CAST(VerseKey, inkey);
-#ifndef _WIN32_WCE
 	}
 	catch ( ... ) {
 	}
-#endif
 	// if we don't have a VerseKey * decendant, create our own
 	if (!srckey)
 		srckey = new VerseKey(inkey);
@@ -191,8 +169,6 @@ SWModule &zCom::operator <<(const SWKey *inkey) {
 
 	if (inkey != srckey) // free our key if we created a VerseKey
 		delete srckey;
-
-	return *this;
 }
 
 /******************************************************************************
@@ -205,14 +181,10 @@ void zCom::deleteEntry() {
 
 	VerseKey *key = 0;
 
-#ifndef _WIN32_WCE
 	try {
-#endif
 		key = SWDYNAMIC_CAST(VerseKey, this->key);
-#ifndef _WIN32_WCE
 	}
 	catch ( ... ) {}
-#endif
 	if (!key)
 		key = new VerseKey(this->key);
 
@@ -224,48 +196,40 @@ void zCom::deleteEntry() {
 
 
 /******************************************************************************
- * zCom::operator +=	- Increments module key a number of entries
+ * zCom::increment	- Increments module key a number of entries
  *
  * ENT:	increment	- Number of entries to jump forward
  *
  * RET: *this
  */
 
-SWModule &zCom::operator +=(int increment) {
+void zCom::increment(int steps) {
 	long  start;
 	unsigned short size;
 	VerseKey *tmpkey = 0;
 
-#ifndef _WIN32_WCE
 	try {
-#endif
 		tmpkey = SWDYNAMIC_CAST(VerseKey, key);
-#ifndef _WIN32_WCE
 	}
 	catch ( ... ) {}
-#endif
 	if (!tmpkey)
 		tmpkey = new VerseKey(key);
 
 	findoffset(tmpkey->Testament(), tmpkey->Index(), &start, &size);
 
 	SWKey lastgood = *tmpkey;
-	while (increment) {
+	while (steps) {
 		long laststart = start;
 		unsigned short lastsize = size;
 		SWKey lasttry = *tmpkey;
-		(increment > 0) ? (*key)++ : (*key)--;
+		(steps > 0) ? (*key)++ : (*key)--;
 		if (tmpkey != key)
 			delete tmpkey;
 		tmpkey = 0;
-#ifndef _WIN32_WCE
 		try {
-#endif
 			tmpkey = SWDYNAMIC_CAST(VerseKey, key);
-#ifndef _WIN32_WCE
 		}
 		catch ( ... ) {}
-#endif
 		if (!tmpkey)
 			tmpkey = new VerseKey(key);
 
@@ -275,8 +239,11 @@ SWModule &zCom::operator +=(int increment) {
 		}
 		long index = tmpkey->Index();
 		findoffset(tmpkey->Testament(), index, &start, &size);
-		if ((((laststart != start) || (lastsize != size))||(!skipConsecutiveLinks)) && (start >= 0) && (size)) {
-			increment += (increment < 0) ? 1 : -1;
+		if (
+			(((laststart != start) || (lastsize != size))	// we're a different entry
+				&& (start > 0) && (size))	// and we actually have a size
+				||(!skipConsecutiveLinks)) {	// or we don't want to skip consecutive links
+			steps += (steps < 0) ? 1 : -1;
 			lastgood = *tmpkey;
 		}
 	}
@@ -284,7 +251,5 @@ SWModule &zCom::operator +=(int increment) {
 
 	if (tmpkey != key)
 		delete tmpkey;
-
-	return *this;
 }
 
