@@ -93,8 +93,7 @@ RawStr4::~RawStr4()
  *		buf		- address of pointer to allocate for storage of string
  */
 
-void RawStr4::getidxbufdat(long ioffset, char **buf)
-{
+void RawStr4::getidxbufdat(long ioffset, char **buf) {
 	int size;
 	char ch;
 	if (datfd > 0) {
@@ -103,14 +102,13 @@ void RawStr4::getidxbufdat(long ioffset, char **buf)
 			if ((ch == '\\') || (ch == 10) || (ch == 13))
 				break;
 		}
-		*buf = (*buf) ? (char *)realloc(*buf, size + 1) : (char *)malloc(size + 1);
+		*buf = (*buf) ? (char *)realloc(*buf, size*2 + 1) : (char *)malloc(size*2 + 1);
 		if (size) {
 			lseek(datfd->getFd(), ioffset, SEEK_SET);
 			read(datfd->getFd(), *buf, size);
 		}
 		(*buf)[size] = 0;
-		for (size--; size > 0; size--)
-			(*buf)[size] = SW_toupper((*buf)[size]);
+		toupperstr_utf8(*buf);
 	}
 	else {
 		*buf = (*buf) ? (char *)realloc(*buf, 1) : (char *)malloc(1);
@@ -141,16 +139,11 @@ void RawStr4::getidxbuf(long ioffset, char **buf)
 
 		getidxbufdat(offset, buf);
 		for (trybuf = targetbuf = *buf; *trybuf; trybuf++, targetbuf++) {
-/*
-			if (*trybuf == '-') {		// ignore '-' because alphabetized silly in file
-				targetbuf--;
-				continue;
-			}
-*/
-			*targetbuf = SW_toupper(*trybuf);
+			*targetbuf = *trybuf;
 		}
 		*targetbuf = 0;
 		trybuf = 0;
+		toupperstr_utf8(targetbuf);
 	}
 }
 
@@ -164,33 +157,25 @@ void RawStr4::getidxbuf(long ioffset, char **buf)
  *		away		- number of entries before of after to jump
  *					(default = 0)
  *
- * RET: error status
+ * RET: error status -1 general error; -2 new file
  */
 
 signed char RawStr4::findoffset(const char *ikey, long *start, unsigned long *size, long away, long *idxoff)
 {
 	char *trybuf, *targetbuf, *key, quitflag = 0;
-        signed char retval = 0;
+	signed char retval = -1;
 	long headoff, tailoff, tryoff = 0, maxoff = 0;
 
 	if (idxfd->getFd() >=0) {
+		tailoff = maxoff = lseek(idxfd->getFd(), 0, SEEK_END) - 8;
+		retval = (tailoff >= 0) ? 0 : -2;	// if NOT new file
 		if (*ikey) {
 			headoff = 0;
-			tailoff = maxoff = lseek(idxfd->getFd(), 0, SEEK_END) - 8;
 
 			key = new char [ strlen(ikey) + 1 ];
 			strcpy(key, ikey);
+			toupperstr_utf8(key);
 
-			for (trybuf = targetbuf = key; *trybuf; trybuf++, targetbuf++) {
-	/*
-				if (*trybuf == '-') {		// ignore '-' because alphabetized silly in file
-					targetbuf--;
-					continue;
-				}
-	*/
-				*targetbuf = SW_toupper(*trybuf);
-			}
-			*targetbuf = 0;
 			trybuf = 0;
 
 			while (headoff < tailoff) {
@@ -338,7 +323,7 @@ void RawStr4::preptext(char *buf)
 
 
 /******************************************************************************
- * RawStr4::gettext	- gets text at a given offset
+ * RawStr4::readtext	- gets text at a given offset
  *
  * ENT:
  *	start	- starting offset where the text is located in the file
@@ -347,36 +332,42 @@ void RawStr4::preptext(char *buf)
  *
  */
 
-void RawStr4::gettext(long istart, unsigned long isize, char *idxbuf, char *buf)
+void RawStr4::readtext(long istart, unsigned long *isize, char **idxbuf, char **buf)
 {
 	char *ch;
 	char *idxbuflocal = 0;
 	getidxbufdat(istart, &idxbuflocal);
 	long start = istart;
-	unsigned long size = isize;
 
 	do {
-		memset(buf, 0, size);
-		lseek(datfd->getFd(), start, SEEK_SET);
-		read(datfd->getFd(), buf, (int)(size - 1));
+		if (*idxbuf)
+			delete [] *idxbuf;
+		if (*buf)
+			delete [] *buf;
+		*buf    = new char [ ++(*isize) * FILTERPAD ];
+		*idxbuf = new char [ (*isize) * FILTERPAD ];
 
-		for (ch = buf; *ch; ch++) {		// skip over index string
+		memset(*buf, 0, *isize);
+		lseek(datfd->getFd(), start, SEEK_SET);
+		read(datfd->getFd(), *buf, (int)((*isize) - 1));
+
+		for (ch = *buf; *ch; ch++) {		// skip over index string
 			if (*ch == 10) {
 				ch++;
 				break;
 			}
 		}
-		memmove(buf, ch, size - (unsigned long)(ch-buf));
+		memmove(*buf, ch, *isize - (unsigned long)(ch-*buf));
 
 		// resolve link
-		if (!strncmp(buf, "@LINK", 5)) {
-			for (ch = buf; *ch; ch++) {		// null before nl
+		if (!strncmp(*buf, "@LINK", 5)) {
+			for (ch = *buf; *ch; ch++) {		// null before nl
 				if (*ch == 10) {
 					*ch = 0;
 					break;
 				}
 			}
-			findoffset(buf + 8, &start, &size);
+			findoffset(*buf + 6, &start, isize);
 		}
 		else break;
 	}
@@ -384,9 +375,9 @@ void RawStr4::gettext(long istart, unsigned long isize, char *idxbuf, char *buf)
 
 	if (idxbuflocal) {
 		int localsize = strlen(idxbuflocal);
-		localsize = (localsize < (size - 1)) ? localsize : (size - 1);
-		strncpy(idxbuf, idxbuflocal, localsize);
-		idxbuf[localsize] = 0;
+		localsize = (localsize < (*isize - 1)) ? localsize : (*isize - 1);
+		strncpy(*idxbuf, idxbuflocal, localsize);
+		(*idxbuf)[localsize] = 0;
 		free(idxbuflocal);
 	}
 }
@@ -400,8 +391,7 @@ void RawStr4::gettext(long istart, unsigned long isize, char *idxbuf, char *buf)
  *      len     - length of buffer (0 - null terminated)
  */
 
-void RawStr4::settext(const char *ikey, const char *buf, long len)
-{
+void RawStr4::setText(const char *ikey, const char *buf, long len) {
 
 	long start, outstart;
 	long idxoff;
@@ -417,19 +407,21 @@ void RawStr4::settext(const char *ikey, const char *buf, long len)
 	char *outbuf = 0;
 	char *ch = 0;
 
-	findoffset(ikey, &start, &size, 0, &idxoff);
+	char errorStatus = findoffset(ikey, &start, &size, 0, &idxoff);
 	stdstr(&key, ikey);
-	for (ch = key; *ch; ch++)
-		*ch = SW_toupper(*ch);
-	ch = 0;
+	toupperstr_utf8(key);
 
+	len = (len < 0) ? strlen(buf) : len;
 	getidxbufdat(start, &dbKey);
 
 	if (strcmp(key, dbKey) < 0) {
 	}
 	else if (strcmp(key, dbKey) > 0) {
-		idxoff += 8;
-	} else if ((!strcmp(key, dbKey)) && (len || strlen(buf) /*we're not deleting*/)) { // got absolute entry
+		if (errorStatus != -2)	// not a new file
+			idxoff += 8;
+		else idxoff = 0;
+	}
+	else if ((!strcmp(key, dbKey)) && (len>0/*we're not deleting*/)) { // got absolute entry
 		do {
 			tmpbuf = new char [ size + 2 ];
 			memset(tmpbuf, 0, size + 2);
@@ -445,7 +437,7 @@ void RawStr4::settext(const char *ikey, const char *buf, long len)
 			memmove(tmpbuf, ch, size - (unsigned long)(ch-tmpbuf));
 
 			// resolve link
-			if (!strncmp(tmpbuf, "@LINK", 5) && (len ? len : strlen(buf))) {
+			if (!strncmp(tmpbuf, "@LINK", 5) && (len > 0)) {
 				for (ch = tmpbuf; *ch; ch++) {		// null before nl
 					if (*ch == 10) {
 						*ch = 0;
@@ -453,6 +445,7 @@ void RawStr4::settext(const char *ikey, const char *buf, long len)
 					}
 				}
 				findoffset(tmpbuf + 8, &start, &size, 0, &idxoff);
+				++size;
 			}
 			else break;
 		}
@@ -469,11 +462,11 @@ void RawStr4::settext(const char *ikey, const char *buf, long len)
 		read(idxfd->getFd(), idxBytes, shiftSize);
 	}
 
-	outbuf = new char [ (len ? len : strlen(buf)) + strlen(key) + 5 ];
+	outbuf = new char [ len + strlen(key) + 5 ];
 	sprintf(outbuf, "%s%c%c", key, 13, 10);
 	size = strlen(outbuf);
-	memcpy (outbuf + size, buf, len ? len : strlen(buf));
-	size = outsize = size + (len ? len : strlen(buf));
+	memcpy(outbuf + size, buf, len);
+	size = outsize = size + len;
 
 	start = outstart = lseek(datfd->getFd(), 0, SEEK_END);
 
@@ -481,7 +474,7 @@ void RawStr4::settext(const char *ikey, const char *buf, long len)
 	outsize  = archtosword32(size);
 
 	lseek(idxfd->getFd(), idxoff, SEEK_SET);
-	if (len ? len : strlen(buf)) {
+	if (len>0) {
 		lseek(datfd->getFd(), start, SEEK_SET);
 		write(datfd->getFd(), outbuf, (long)size);
 
@@ -521,7 +514,7 @@ void RawStr4::settext(const char *ikey, const char *buf, long len)
 void RawStr4::linkentry(const char *destkey, const char *srckey) {
 	char *text = new char [ strlen(destkey) + 7 ];
 	sprintf(text, "@LINK %s", destkey);
-	settext(srckey, text);
+	setText(srckey, text);
 	delete [] text;
 }
 
