@@ -33,7 +33,8 @@
  * RawVerse Statics
  */
 
- int RawVerse::instance = 0;
+int RawVerse::instance = 0;
+const char *RawVerse::nl = "\r\n";
 
 
 /******************************************************************************
@@ -48,7 +49,6 @@ RawVerse::RawVerse(const char *ipath, int fileMode)
 {
 	char *buf;
 
-	nl = '\n';
 	path = 0;
 	stdstr(&path, ipath);
      buf = new char [ strlen(path) + 80 ];
@@ -151,14 +151,16 @@ void RawVerse::preptext(char *buf)
 			nlcnt++;
 			if (nlcnt > 1) {
 //				*to++ = nl;
-				*to++ = nl;
+				*to++ = 10;
+//				*to++ = nl[1];
 //				nlcnt = 0;
 			}
 			continue;
 		case 13:
 			if (!realdata)
 				continue;
-			*to++ = nl;
+//			*to++ = nl[0];
+			*to++ = 10;
 			space = 0;
 			cr = 1;
 			continue;
@@ -187,7 +189,7 @@ void RawVerse::preptext(char *buf)
 
 
 /******************************************************************************
- * RawVerse::gettext	- gets text at a given offset
+ * RawVerse::readtext	- gets text at a given offset
  *
  * ENT:	testmt	- testament file to search in (0 - Old; 1 - New)
  *	start	- starting offset where the text is located in the file
@@ -196,8 +198,10 @@ void RawVerse::preptext(char *buf)
  *
  */
 
-void RawVerse::gettext(char testmt, long start, unsigned short size, char *buf) {
-	memset(buf, 0, size+1);
+void RawVerse::readtext(char testmt, long start, unsigned short size, char *buf) {
+	memset(buf, 0, size);
+	if (!testmt)
+		testmt = ((idxfp[1]) ? 1:2);
 	if (size) {
 		if (textfp[testmt-1]->getFd() >= 0) {
 			lseek(textfp[testmt-1]->getFd(), start, SEEK_SET);
@@ -221,13 +225,12 @@ void RawVerse::settext(char testmt, long idxoff, const char *buf, long len)
 	long start, outstart;
 	unsigned short size;
 	unsigned short outsize;
-	static const char nl[] = {13, 10};
 
 	idxoff *= 6;
 	if (!testmt)
 		testmt = ((idxfp[1]) ? 1:2);
 
-	size = outsize = len ? len : strlen(buf);
+	size = outsize = (len < 0) ? strlen(buf) : len;
 
 	start = outstart = lseek(textfp[testmt-1]->getFd(), 0, SEEK_END);
 	lseek(idxfp[testmt-1]->getFd(), idxoff, SEEK_SET);
@@ -237,7 +240,7 @@ void RawVerse::settext(char testmt, long idxoff, const char *buf, long len)
 		write(textfp[testmt-1]->getFd(), buf, (int)size);
 
 		// add a new line to make data file easier to read in an editor
-		write(textfp[testmt-1]->getFd(), &nl, 2);
+		write(textfp[testmt-1]->getFd(), nl, 2);
 	}
 	else {
 		start = 0;
