@@ -124,14 +124,13 @@ void zStr::getKeyFromDatOffset(long ioffset, char **buf) {
 			if ((ch == '\\') || (ch == 10) || (ch == 13))
 				break;
 		}
-		*buf = (*buf) ? (char *)realloc(*buf, size + 1) : (char *)malloc(size + 1);
+		*buf = (*buf) ? (char *)realloc(*buf, size*2 + 1) : (char *)malloc(size*2 + 1);
 		if (size) {
 			lseek(datfd->getFd(), ioffset, SEEK_SET);
 			read(datfd->getFd(), *buf, size);
 		}
 		(*buf)[size] = 0;
-		for (size--; size > 0; size--)
-			(*buf)[size] = SW_toupper((*buf)[size]);
+		toupperstr_utf8(*buf);
 	}
 	else {
 		*buf = (*buf) ? (char *)realloc(*buf, 1) : (char *)malloc(1);
@@ -184,7 +183,7 @@ signed char zStr::findKeyIndex(const char *ikey, long *idxoff, long away) {
 		if (*ikey) {
 			headoff = 0;
 			stdstr(&key, ikey);
-			toupperstr(key);
+			toupperstr_utf8(key);
 
 			while (headoff < tailoff) {
 				tryoff = (lastoff == -1) ? headoff + (((((tailoff / IDXENTRYSIZE) - (headoff / IDXENTRYSIZE))) / 2) * IDXENTRYSIZE) : lastoff;
@@ -330,7 +329,7 @@ void zStr::prepText(char *buf) {
 
 
 /******************************************************************************
- * zStr::gettext	- gets text at a given offset
+ * zStr::getText	- gets text at a given offset
  *
  * ENT:
  *	offset	- idxoffset where the key is located.
@@ -355,8 +354,8 @@ void zStr::getText(long offset, char **idxbuf, char **buf) {
 		start = swordtoarch32(start);
 		size = swordtoarch32(size);
 
-		*buf = (*buf) ? (char *)realloc(*buf, size + 1) : (char *)malloc(size + 1);
-		*idxbuf = (*idxbuf) ? (char *)realloc(*idxbuf, size + 1) : (char *)malloc(size + 1);
+		*buf = (*buf) ? (char *)realloc(*buf, size*2 + 1) : (char *)malloc(size*2 + 1);
+		*idxbuf = (*idxbuf) ? (char *)realloc(*idxbuf, size*2 + 1) : (char *)malloc(size*2 + 1);
 		memset(*buf, 0, size + 1);
 		memset(*idxbuf, 0, size + 1);
 		lseek(datfd->getFd(), start, SEEK_SET);
@@ -378,7 +377,7 @@ void zStr::getText(long offset, char **idxbuf, char **buf) {
 					break;
 				}
 			}
-			findKeyIndex(*buf + IDXENTRYSIZE, &offset);
+			findKeyIndex(*buf + 6, &offset);
 		}
 		else break;
 	}
@@ -419,7 +418,7 @@ void zStr::getCompressedText(long block, long entry, char **buf) {
 		start = swordtoarch32(start);
 		size = swordtoarch32(size);
 
-		*buf = (*buf) ? (char *)realloc(*buf, size + 1) : (char *)malloc(size + 1);
+		*buf = (*buf) ? (char *)realloc(*buf, size*2 + 1) : (char *)malloc(size*2 + 1);
 
 		lseek(zdtfd->getFd(), start, SEEK_SET);
 		read(zdtfd->getFd(), *buf, size);
@@ -427,13 +426,16 @@ void zStr::getCompressedText(long block, long entry, char **buf) {
 		flushCache();
 
 		unsigned long len = size;
+
+		rawZFilter(*buf, len, 0); // 0 = decipher
+
 		compressor->zBuf(&len, *buf);
 		char * rawBuf = compressor->Buf(0, &len);
 		cacheBlock = new EntriesBlock(rawBuf, len);
 		cacheBlockIndex = block;
 	}
 	size = cacheBlock->getEntrySize(entry);
-	*buf = (*buf) ? (char *)realloc(*buf, size + 1) : (char *)malloc(size + 1);
+	*buf = (*buf) ? (char *)realloc(*buf, size*2 + 1) : (char *)malloc(size*2 + 1);
 	strcpy(*buf, cacheBlock->getEntry(entry));
 }
 
@@ -461,8 +463,9 @@ void zStr::setText(const char *ikey, const char *buf, long len) {
 	char *outbuf = 0;
 	char *ch = 0;
 
+	len = (len < 0) ? strlen(buf) : len;
 	stdstr(&key, ikey);
-	toupperstr(key);
+	toupperstr_utf8(key);
 
 	char notFound = findKeyIndex(ikey, &idxoff, 0);
 	if (!notFound) {
@@ -473,7 +476,7 @@ void zStr::setText(const char *ikey, const char *buf, long len) {
 		else if (diff > 0) {
 			idxoff += IDXENTRYSIZE;
 		}
-		else if ((!diff) && (len || strlen(buf) /*we're not deleting*/)) { // got absolute entry
+		else if ((!diff) && (len > 0 /*we're not deleting*/)) { // got absolute entry
 			do {
 				lseek(idxfd->getFd(), idxoff, SEEK_SET);
 				read(idxfd->getFd(), &start, sizeof(__u32));
@@ -495,7 +498,7 @@ void zStr::setText(const char *ikey, const char *buf, long len) {
 				memmove(tmpbuf, ch, size - (unsigned long)(ch-tmpbuf));
 
 				// resolve link
-				if (!strncmp(tmpbuf, "@LINK", 5) && (len ? len : strlen(buf))) {
+				if (!strncmp(tmpbuf, "@LINK", 5) && (len)) {
 					for (ch = tmpbuf; *ch; ch++) {		// null before nl
 						if (*ch == 10) {
 							*ch = 0;
@@ -521,10 +524,10 @@ void zStr::setText(const char *ikey, const char *buf, long len) {
 		read(idxfd->getFd(), idxBytes, shiftSize);
 	}
 
-	outbuf = new char [ (len ? len : strlen(buf)) + strlen(key) + 5 ];
+	outbuf = new char [ len + strlen(key) + 5 ];
 	sprintf(outbuf, "%s%c%c", key, 13, 10);
 	size = strlen(outbuf);
-	if (len ? len : strlen(buf)) {	// NOT a link
+	if (len > 0) {	// NOT a link
 		if (!cacheBlock) {
 			flushCache();
 			cacheBlock = new EntriesBlock();
@@ -544,8 +547,8 @@ void zStr::setText(const char *ikey, const char *buf, long len) {
 		size += (sizeof(__u32) * 2);
 	}
 	else {	// link
-		memcpy(outbuf + size, buf, len ? len : strlen(buf));
-		size += (len ? len : strlen(buf));
+		memcpy(outbuf + size, buf, len);
+		size += len;
 	}
 
 	start = lseek(datfd->getFd(), 0, SEEK_END);
@@ -554,7 +557,7 @@ void zStr::setText(const char *ikey, const char *buf, long len) {
 	outsize  = archtosword32(size);
 
 	lseek(idxfd->getFd(), idxoff, SEEK_SET);
-	if (len ? len : strlen(buf)) {
+	if (len > 0) {
 		lseek(datfd->getFd(), start, SEEK_SET);
 		write(datfd->getFd(), outbuf, size);
 
@@ -610,6 +613,10 @@ void zStr::flushCache() {
 			compressor->Buf(rawBuf, &size);
 			compressor->zBuf(&size);
 
+			char *buf = new char [ size * 2 ];
+			memcpy(buf, compressor->zBuf(&size), size); // 1 = encipher
+			rawZFilter(buf, size, 1); // 1 = encipher
+
 			long zdxSize = lseek(zdxfd->getFd(), 0, SEEK_END);
 			long zdtSize = lseek(zdtfd->getFd(), 0, SEEK_END);
 
@@ -640,8 +647,7 @@ void zStr::flushCache() {
 
 			lseek(zdxfd->getFd(), cacheBlockIndex * ZDXENTRYSIZE, SEEK_SET);
 			lseek(zdtfd->getFd(), start, SEEK_SET);
-			rawBuf = compressor->zBuf(&size);
-			write(zdtfd->getFd(), rawBuf, size);
+			write(zdtfd->getFd(), buf, size);
 
 			// add a new line to make data file easier to read in an editor
 			write(zdtfd->getFd(), &nl, 2);
