@@ -228,6 +228,9 @@ void zVerse::findoffset(char testmt, long idxoff, long *start, unsigned short *s
 			printf ("Error reading compressed text\n");
 			return;
 		}
+
+		rawZFilter(pcCompText, ulCompSize, 0); // 0 = decipher
+		
 		compressor->zBuf(&ulCompSize, pcCompText);
 
 		if (cacheBuf) {
@@ -242,12 +245,14 @@ void zVerse::findoffset(char testmt, long idxoff, long *start, unsigned short *s
 
 		cacheTestament = testmt;
 		cacheBufIdx = ulBuffNum;
+		if (pcCompText)
+			delete [] pcCompText;
 	}
 }
 
 
 /******************************************************************************
- * zVerse::swgettext	- gets text at a given offset
+ * zVerse::zreadtext	- gets text at a given offset
  *
  * ENT:	testmt	- testament file to search in (0 - Old; 1 - New)
  *	start	- starting offset where the text is located in the file
@@ -256,11 +261,12 @@ void zVerse::findoffset(char testmt, long idxoff, long *start, unsigned short *s
  *
  */
 
-void zVerse::swgettext(char testmt, long start, unsigned short size, char *inbuf)
+void zVerse::zreadtext(char testmt, long start, unsigned short size, char *inbuf)
 {
 	memset(inbuf, 0, size);
 	if (size > 2) {
-		strncpy(inbuf, &(cacheBuf[start]), size-2);
+		if (cacheBuf)
+			strncpy(inbuf, &(cacheBuf[start]), size-2);
 	}
 }
 
@@ -274,16 +280,19 @@ void zVerse::swgettext(char testmt, long start, unsigned short size, char *inbuf
  *      len     - length of buffer (0 - null terminated)
  */
 
-void zVerse::settext(char testmt, long idxoff, const char *buf, long len)
-{
+void zVerse::settext(char testmt, long idxoff, const char *buf, long len) {
+
+	len = (len < 0) ? strlen(buf) : len;
+	if (!testmt) 
+		testmt = ((idxfp[0]) ? 1:2);
 	if ((!dirtyCache) || (cacheBufIdx < 0)) {
 		cacheBufIdx = lseek(idxfp[testmt-1]->getFd(), 0, SEEK_END) / 12;
 		cacheTestament = testmt;
 		if (cacheBuf)
 			free(cacheBuf);
-		cacheBuf = (char *)calloc(len ? len : strlen(buf)+1, 1);
+		cacheBuf = (char *)calloc(len + 1, 1);
 	}
-	else cacheBuf = (char *)((cacheBuf)?realloc(cacheBuf, strlen(cacheBuf)+(len ? len : strlen(buf)+1)):calloc((len ? len : strlen(buf)+1), 1));
+	else cacheBuf = (char *)((cacheBuf)?realloc(cacheBuf, strlen(cacheBuf)+(len + 1)):calloc((len + 1), 1));
 
 	dirtyCache = true;
 
@@ -293,7 +302,7 @@ void zVerse::settext(char testmt, long idxoff, const char *buf, long len)
 	unsigned short outsize;
 
 	idxoff *= 10;
-	size = outsize = len ? len : strlen(buf);
+	size = outsize = len;
 
 	start = strlen(cacheBuf);
 
@@ -320,28 +329,38 @@ void zVerse::flushCache() {
 		unsigned long zsize, outzsize;
 
 		idxoff = cacheBufIdx * 12;
-		size = outsize = zsize = outzsize = strlen(cacheBuf);
-		if (size) {
-//			if (compressor) {
-//				delete compressor;
-//				compressor = new LZSSCompress();
-//			}
-			compressor->Buf(cacheBuf);
-			compressor->zBuf(&zsize);
-			outzsize = zsize;
+		if (cacheBuf) {
+			size = outsize = zsize = outzsize = strlen(cacheBuf);
+			if (size) {
+	//			if (compressor) {
+	//				delete compressor;
+	//				compressor = new LZSSCompress();
+	//			}
+				compressor->Buf(cacheBuf);
+				compressor->zBuf(&zsize);
+				outzsize = zsize;
 
-			start = outstart = lseek(textfp[cacheTestament-1]->getFd(), 0, SEEK_END);
+				char *buf = new char [ zsize * 2 ];
+				memcpy(buf, compressor->zBuf(&zsize), zsize);
+				rawZFilter(buf, zsize, 1); // 1 = encipher
 
-			outstart  = archtosword32(start);
-			outsize   = archtosword32(size);
-			outzsize  = archtosword32(zsize);
+				start = outstart = lseek(textfp[cacheTestament-1]->getFd(), 0, SEEK_END);
 
-			write(textfp[cacheTestament-1]->getFd(), compressor->zBuf(&zsize), zsize);
+				outstart  = archtosword32(start);
+				outsize   = archtosword32(size);
+				outzsize  = archtosword32(zsize);
 
-			lseek(idxfp[cacheTestament-1]->getFd(), idxoff, SEEK_SET);
-			write(idxfp[cacheTestament-1]->getFd(), &outstart, 4);
-			write(idxfp[cacheTestament-1]->getFd(), &outzsize, 4);
-			write(idxfp[cacheTestament-1]->getFd(), &outsize, 4);
+				write(textfp[cacheTestament-1]->getFd(), buf, zsize);
+
+				delete [] buf;
+
+				lseek(idxfp[cacheTestament-1]->getFd(), idxoff, SEEK_SET);
+				write(idxfp[cacheTestament-1]->getFd(), &outstart, 4);
+				write(idxfp[cacheTestament-1]->getFd(), &outzsize, 4);
+				write(idxfp[cacheTestament-1]->getFd(), &outsize, 4);
+			}
+			free(cacheBuf);
+			cacheBuf = 0;
 		}
 		dirtyCache = false;
 	}
