@@ -47,10 +47,14 @@ char GBFRTF::ProcessText(char *text, int maxlen, const SWKey *key, const SWModul
 				case 'H':               // Hebrew
 					*to++ = '{';
 					*to++ = '\\';
+					*to++ = 'c';
 					*to++ = 'f';
+					*to++ = '3';
+					*to++ = ' ';
+					*to++ = '\\';
 					*to++ = 's';
-					*to++ = '1';
-					*to++ = '7';
+					*to++ = 'u';
+					*to++ = 'b';
 					*to++ = ' ';
 					*to++ = '<';
 					for (tok = token + 2; *tok; tok++)
@@ -62,10 +66,14 @@ char GBFRTF::ProcessText(char *text, int maxlen, const SWKey *key, const SWModul
 				case 'T':               // Tense
 					*to++ = '{';
 					*to++ = '\\';
+					*to++ = 'c';
 					*to++ = 'f';
+					*to++ = '4';
+					*to++ = ' ';
+					*to++ = '\\';
 					*to++ = 's';
-					*to++ = '1';
-					*to++ = '7';
+					*to++ = 'u';
+					*to++ = 'b';
 					*to++ = ' ';
 					*to++ = '(';
 					bool separate = false;
@@ -103,10 +111,23 @@ char GBFRTF::ProcessText(char *text, int maxlen, const SWKey *key, const SWModul
 			case 'R':
 				switch(token[1]) {
 				case 'X':
-				  *to++ = '#';
+				  *to++ = '<';
+				  *to++ = 'a';
+				  *to++ = ' ';
+				  *to++ = 'h';
+				  *to++ = 'r';
+				  *to++ = 'e';
+				  *to++ = 'f';
+				  *to++ = '=';
+				  *to++ = '"';
+				  *to++ = '"';
+				  *to++ = '>';
 				  continue;
 				case 'x':
-				  *to++ = '|';
+				  *to++ = '<';
+				  *to++ = '/';
+				  *to++ = 'a';
+				  *to++ = '>';
 				  continue;
 				case 'F':               // footnote begin
 					*to++ = '{';
@@ -115,10 +136,9 @@ char GBFRTF::ProcessText(char *text, int maxlen, const SWKey *key, const SWModul
 					*to++ = '1';
 					*to++ = ' ';
 					*to++ = '\\';
-					*to++ = 'f';
 					*to++ = 's';
-					*to++ = '1';
-					*to++ = '7';
+					*to++ = 'u';
+					*to++ = 'b';
 					*to++ = ' ';
 					*to++ = '(';
 					continue;
@@ -156,8 +176,8 @@ char GBFRTF::ProcessText(char *text, int maxlen, const SWKey *key, const SWModul
 					*to++ = ' ';
 					continue;
 				case 'N':
-				        *to++ = '{';
-				        if (!strnicmp(token+2, "Symbol", 6)) {
+					   *to++ = '{';
+					   if (!strnicmp(token+2, "Symbol", 6)) {
 					  *to++ = '\\';
 					  *to++ = 'f';
 					  *to++ = '7';
@@ -168,8 +188,8 @@ char GBFRTF::ProcessText(char *text, int maxlen, const SWKey *key, const SWModul
 					*to++ = '}';
 					continue;
 				case 'S':
-				        *to++ = '{';
-				        *to++ = '\\';
+					   *to++ = '{';
+					   *to++ = '\\';
 					*to++ = 's';
 					*to++ = 'u';
 					*to++ = 'p';
@@ -178,10 +198,10 @@ char GBFRTF::ProcessText(char *text, int maxlen, const SWKey *key, const SWModul
 					*to++ = ' ';
 					continue;
 				case 's':
-       				        *to++ = '}';
+						   *to++ = '}';
 					continue;
 				case 'R':
-				        *to++ = '{';
+					   *to++ = '{';
 					*to++ = '\\';
 					*to++ = 'c';
 					*to++ = 'f';
@@ -189,7 +209,7 @@ char GBFRTF::ProcessText(char *text, int maxlen, const SWKey *key, const SWModul
 					*to++ = ' ';
 					continue;
 				case 'r':
-				        *to++ = '}';
+					   *to++ = '}';
 					continue;
 				}
 				break;
@@ -226,22 +246,23 @@ char GBFRTF::ProcessText(char *text, int maxlen, const SWKey *key, const SWModul
 			    case 'T':               // Book title begin
 			      *to++ = '{';
 			      *to++ = '\\';
-			      *to++ = 'f';
-			      *to++ = 's';
-			      *to++ = '2';
-			      *to++ = '2';
-			      *to++ = ' ';
-			      continue;
+				 *to++ = 'l';
+				 *to++ = 'a';
+				 *to++ = 'r';
+				 *to++ = 'g';
+				 *to++ = 'e';
+				 *to++ = ' ';
+				 continue;
 			    case 't':
-			      *to++ = '}';
-			      continue;
+				 *to++ = '}';
+				 continue;
 			    case 'S':
-			      *to++ = '\\';
-			      *to++ = 'p';
-			      *to++ = 'a';
-			      *to++ = 'r';
-			      *to++ = ' ';
-			      *to++ = '{';
+				 *to++ = '\\';
+				 *to++ = 'p';
+				 *to++ = 'a';
+				 *to++ = 'r';
+				 *to++ = ' ';
+				 *to++ = '{';
 			      *to++ = '\\';
 			      *to++ = 'i';
 			      *to++ = '1';
