@@ -18,7 +18,8 @@ char Latin1UTF8::ProcessText(char *text, int maxlen, const SWKey *key, const SWM
 {
     unsigned char *to, *from;
 	int len;
-
+	 if ((unsigned long)key < 2)	// hack, we're en(1)/de(0)ciphering
+		return -1;
         len = strlen(text) + 1;
 	if (len == maxlen + 1)
         	maxlen = (maxlen + 1) * FILTERPAD;
