@@ -21,6 +21,8 @@ char UTF16UTF8::ProcessText(char *text, int maxlen, const SWKey *key, const SWMo
   int len;
   unsigned long uchar;
   unsigned short schar;
+	 if ((unsigned long)key < 2)	// hack, we're en(1)/de(0)ciphering
+		return -1;
 
   len = 0;
   from = (unsigned short*) text;
