@@ -25,6 +25,8 @@ UTF8NFC::~UTF8NFC() {
 
 char UTF8NFC::ProcessText(char *text, int maxlen, const SWKey *key, const SWModule *module)
 {
+	 if ((unsigned long)key < 2)	// hack, we're en(1)/de(0)ciphering
+		return -1;
         int32_t len = strlen(text) * 2;
         source = new UChar[len + 1]; //each char could become a surrogate pair
 
