@@ -15,6 +15,19 @@
 
 #include <utf8transliterator.h>
 
+#ifndef _ICUSWORD_
+#include "unicode/resbund.h"
+#endif
+#include <swlog.h>
+
+#ifdef _ICU_
+class UnicodeCaster {
+	const UnicodeString &ustr;
+public:
+	UnicodeCaster(const UnicodeString &ustr):ustr(ustr) {}; operator const char *() { return ""; };
+};
+
+#endif
 const char UTF8Transliterator::optionstring[NUMTARGETSCRIPTS][16] = {
         "Off",
         "Latin",
@@ -25,7 +38,7 @@ const char UTF8Transliterator::optionstring[NUMTARGETSCRIPTS][16] = {
         "Greek",
         "Hebrew",
         "Cyrillic",
-        "Arabic",
+	   "Arabic",
         "Syriac",
         "Katakana",
         "Hiragana",
@@ -53,12 +66,233 @@ const char UTF8Transliterator::optionstring[NUMTARGETSCRIPTS][16] = {
 const char UTF8Transliterator::optName[] = "Transliteration";
 const char UTF8Transliterator::optTip[] = "Transliterates between scripts";
 
+SWTransMap UTF8Transliterator::transMap;
+
+#ifndef _ICUSWORD_
+
+const char UTF8Transliterator::SW_RB_RULE_BASED_IDS[] = "RuleBasedTransliteratorIDs";
+const char UTF8Transliterator::SW_RB_RULE[] = "Rule";
+#ifdef SWICU_DATA
+const char UTF8Transliterator::SW_RESDATA[] = SWICU_DATA;
+#else
+const char UTF8Transliterator::SW_RESDATA[] = "/usr/local/lib/sword/";
+#endif
+
+class SWCharString {
+ public:
+    inline SWCharString(const UnicodeString& str);
+    inline ~SWCharString();
+    inline operator const char*() { return ptr; }
+ private:
+    char buf[128];
+    char* ptr;
+};
+SWCharString::SWCharString(const UnicodeString& str) {
+    // TODO This isn't quite right -- we should probably do
+    // preflighting here to determine the real length.
+    if (str.length() >= (int32_t)sizeof(buf)) {
+        ptr = new char[str.length() + 8];
+    } else {
+        ptr = buf;
+    }
+    str.extract(0, 0x7FFFFFFF, ptr, "");
+}
+
+SWCharString::~SWCharString() {
+    if (ptr != buf) {
+        delete[] ptr;
+    }
+}
+
+#endif // _ICUSWORD_
+
+
 UTF8Transliterator::UTF8Transliterator() {
 	option = 0;
         unsigned long i;
 	for (i = 0; i < NUMTARGETSCRIPTS; i++) {
 		options.push_back(optionstring[i]);
 	}
+#ifndef _ICUSWORD_
+	utf8status = U_ZERO_ERROR;
+	Load(utf8status);
+#endif
+}
+
+void UTF8Transliterator::Load(UErrorCode &status)
+{
+#ifndef _ICUSWORD_
+	static const char translit_swordindex[] = "translit_swordindex";
+	
+    UResourceBundle *bundle, *transIDs, *colBund;
+    bundle = ures_openDirect(SW_RESDATA, translit_swordindex, &status);
+    if (U_FAILURE(status)) {
+		SWLog::systemlog->LogError("no resource index to load");
+		SWLog::systemlog->LogError("status %s", u_errorName(status));
+		return;
+	}
+
+    transIDs = ures_getByKey(bundle, SW_RB_RULE_BASED_IDS, 0, &status);
+	UParseError parseError;
+
+    int32_t row, maxRows;
+    if (U_SUCCESS(status)) {
+	   maxRows = ures_getSize(transIDs);
+	   for (row = 0; row < maxRows; row++) {
+		  colBund = ures_getByIndex(transIDs, row, 0, &status);
+
+		  if (U_SUCCESS(status) && ures_getSize(colBund) == 4) {
+			 UnicodeString id = ures_getUnicodeStringByIndex(colBund, 0, &status);
+			 UChar type = ures_getUnicodeStringByIndex(colBund, 1, &status).charAt(0);
+			 UnicodeString resString = ures_getUnicodeStringByIndex(colBund, 2, &status);
+				SWLog::systemlog->LogInformation("ok so far");
+
+			 if (U_SUCCESS(status)) {
+				switch (type) {
+				case 0x66: // 'f'
+				case 0x69: // 'i'
+				    // 'file' or 'internal';
+				    // row[2]=resource, row[3]=direction
+				    {
+					   UBool visible = (type == 0x0066 /*f*/);
+					   UTransDirection dir =
+						  (ures_getUnicodeStringByIndex(colBund, 3, &status).charAt(0) ==
+						   0x0046 /*F*/) ?
+						  UTRANS_FORWARD : UTRANS_REVERSE;
+					   //registry->put(id, resString, dir, visible);
+			    SWLog::systemlog->LogInformation("instantiating %s ...", (const char *)(UnicodeCaster)resString);
+			    registerTrans(id, resString, dir, status);
+				SWLog::systemlog->LogInformation("done.");
+				    }
+				    break;
+				case 0x61: // 'a'
+				    // 'alias'; row[2]=createInstance argument
+				    //registry->put(id, resString, TRUE);
+				    break;
+				}
+			 }
+		else SWLog::systemlog->LogError("Failed to get resString");
+		  }
+	    else SWLog::systemlog->LogError("Failed to get row");
+
+		  ures_close(colBund);
+	   }
+    }
+	else
+	{
+		SWLog::systemlog->LogError("no resource index to load");
+		SWLog::systemlog->LogError("status %s", u_errorName(status));
+	}
+
+    ures_close(transIDs);
+    ures_close(bundle);
+	
+#endif // _ICUSWORD_
+}
+
+void  UTF8Transliterator::registerTrans(const UnicodeString& ID, const UnicodeString& resource,
+		UTransDirection dir, UErrorCode &status )
+{
+#ifndef _ICUSWORD_
+		SWLog::systemlog->LogInformation("registering ID locally %s", (const char *)(UnicodeCaster)ID);
+		SWTransData swstuff; 
+		swstuff.resource = resource;
+		swstuff.dir = dir;
+		SWTransPair swpair;
+		swpair.first = ID;
+		swpair.second = swstuff;
+		transMap.insert(swpair);
+#endif
+}
+
+bool UTF8Transliterator::checkTrans(const UnicodeString& ID, UErrorCode &status )
+{
+#ifndef _ICUSWORD_
+		Transliterator *trans = Transliterator::createInstance(ID, UTRANS_FORWARD, status);
+		if (!U_FAILURE(status))
+		{
+			// already have it, clean up and return true
+			SWLog::systemlog->LogInformation("already have it %s", (const char *)(UnicodeCaster)ID);
+			delete trans;
+			return true;
+		}
+		status = U_ZERO_ERROR;
+	
+	SWTransMap::iterator swelement;
+	if ((swelement = transMap.find(ID)) != transMap.end())
+	{
+		SWLog::systemlog->LogInformation("found element in map");
+		SWTransData swstuff = (*swelement).second;
+		UParseError parseError;
+		//UErrorCode status;
+		//std::cout << "unregistering " << ID << std::endl;
+		//Transliterator::unregister(ID);
+		SWLog::systemlog->LogInformation("resource is %s", (const char *)(UnicodeCaster)swstuff.resource);
+		
+		// Get the rules
+		//std::cout << "importing: " << ID << ", " << resource << std::endl;
+		SWCharString ch(swstuff.resource);
+		UResourceBundle *bundle = ures_openDirect(SW_RESDATA, ch, &status);
+		const UnicodeString rules = ures_getUnicodeStringByKey(bundle, SW_RB_RULE, &status);
+		ures_close(bundle);
+		//parser.parse(rules, isReverse ? UTRANS_REVERSE : UTRANS_FORWARD,
+		//        parseError, status);
+		if (U_FAILURE(status)) {
+			SWLog::systemlog->LogError("Failed to get rules");
+			SWLog::systemlog->LogError("status %s", u_errorName(status));
+			return false;
+		}
+
+		
+		Transliterator *trans = Transliterator::createFromRules(ID, rules, swstuff.dir,
+			parseError,status);
+		if (U_FAILURE(status)) {
+			SWLog::systemlog->LogError("Failed to create transliterator");
+			SWLog::systemlog->LogError("status %s", u_errorName(status));
+			SWLog::systemlog->LogError("Parse error: line %s", parseError.line);
+			SWLog::systemlog->LogError("Parse error: offset %d", parseError.offset);
+			SWLog::systemlog->LogError("Parse error: preContext %s", *parseError.preContext);
+			SWLog::systemlog->LogError("Parse error: postContext %s", *parseError.postContext);
+			SWLog::systemlog->LogError("rules were");
+//			SWLog::systemlog->LogError((const char *)rules);
+			return false;
+		}
+
+		Transliterator::registerInstance(trans);
+		return true;
+		
+		//Transliterator *trans = instantiateTrans(ID, swstuff.resource, swstuff.dir, parseError, status);
+		//return trans;
+	}
+	else
+	{
+		return false;
+	}
+#else
+return true;
+#endif // _ICUSWORD_
+}
+
+Transliterator * UTF8Transliterator::createTrans(const UnicodeString& preID, const UnicodeString& ID, 
+	const UnicodeString& postID, UTransDirection dir, UErrorCode &status )
+{
+	// extract id to check from ID xxx;id;xxx
+	if (checkTrans(ID, status)) {
+		UnicodeString fullID = preID;
+		fullID += ID;
+		fullID += postID;
+		Transliterator *trans = Transliterator::createInstance(fullID,UTRANS_FORWARD,status);
+		if (U_FAILURE(status)) {
+			delete trans;
+			return NULL;
+		}
+		else {
+			return trans;
+		}
+	}
+	else {
+		return NULL;
+	}
 }
 
 void UTF8Transliterator::setOptionValue(const char *ival)
@@ -168,108 +402,109 @@ char UTF8Transliterator::ProcessText(char *text, int maxlen, const SWKey *key, c
                         return 0;
                 }
 
-                UnicodeString id;
+                UnicodeString preid;
                 if (compat) {
-                        id = UnicodeString("NFKD");
+                        preid = UnicodeString("NFKD;");
                 }
                 else {
-                        id = UnicodeString("NFD");
+                        preid = UnicodeString("NFD;");
                 }
 
 		//Simple X to Latin transliterators
+		UnicodeString id;
 		if (scripts[SE_GREEK]) {
 			if (option == SE_BETA)
-				id += UnicodeString(";Greek-Beta");
+				id = UnicodeString("Greek-Beta");
 			else if (option == SE_BGREEK)
-				id += UnicodeString(";Greek-BGreek");
+				id = UnicodeString("Greek-BGreek");
 			else {
 	            if (!strnicmp (((SWModule*)module)->Lang(), "cop", 3)) {
-        				id += UnicodeString(";Coptic-Latin");
+        				id = UnicodeString("Coptic-Latin");
                 }
                 else {
-		   				id += UnicodeString(";Greek-Latin");
+		   				id = UnicodeString("Greek-Latin");
                 }
 				scripts[SE_LATIN] = true;
 			}
 		}
 		if (scripts[SE_HEBREW]) {
 			if (option == SE_BETA)
-				id += UnicodeString(";Hebrew-CCAT");
+				id = UnicodeString("Hebrew-CCAT");
                         else if (option == SE_SYRIAC)
-                                id += UnicodeString(";Hebrew-Syriac");
+                                id = UnicodeString("Hebrew-Syriac");
 			else {
-				id += UnicodeString(";Hebrew-Latin");
+				id = UnicodeString("Hebrew-Latin");
 				scripts[SE_LATIN] = true;
 			}
 		}
 		if (scripts[SE_CYRILLIC]) {
-			id += UnicodeString(";Cyrillic-Latin");
+			id = UnicodeString("Cyrillic-Latin");
 			scripts[SE_LATIN] = true;
 		}
 		if (scripts[SE_ARABIC]) {
-			id += UnicodeString(";Arabic-Latin");
+			id = UnicodeString("Arabic-Latin");
 			scripts[SE_LATIN] = true;
 		}
 		if (scripts[SE_SYRIAC]) {
                         if (option == SE_BETA)
-        			id += UnicodeString(";Syriac-CCAT");
+        			id = UnicodeString("Syriac-CCAT");
                         else if (option == SE_HEBREW)
-                                id += UnicodeString(";Syriac-Hebrew");
+                                id = UnicodeString("Syriac-Hebrew");
                         else {
-        			id += UnicodeString(";Syriac-Latin");
+        			id = UnicodeString("Syriac-Latin");
         			scripts[SE_LATIN] = true;
                         }
 		}
 		if (scripts[SE_THAI]) {
-			id += UnicodeString(";Thai-Latin");
+			id = UnicodeString("Thai-Latin");
 			scripts[SE_LATIN] = true;
 		}
 		if (scripts[SE_GEORGIAN]) {
-			id += UnicodeString(";Georgian-Latin");
+			id = UnicodeString("Georgian-Latin");
 			scripts[SE_LATIN] = true;
 		}
 		if (scripts[SE_ARMENIAN]) {
-			id += UnicodeString(";Armenian-Latin");
+			id = UnicodeString("Armenian-Latin");
 			scripts[SE_LATIN] = true;
 		}                
 		if (scripts[SE_ETHIOPIC]) {
-			id += UnicodeString(";Ethiopic-Latin");
+			id = UnicodeString("Ethiopic-Latin");
 			scripts[SE_LATIN] = true;
 		}
 		if (scripts[SE_GOTHIC]) {
-			id += UnicodeString(";Gothic-Latin");
+			id = UnicodeString("Gothic-Latin");
 			scripts[SE_LATIN] = true;
 		}
 		if (scripts[SE_UGARITIC]) {
-			id += UnicodeString(";Ugaritic-Latin");
+			id = UnicodeString("Ugaritic-Latin");
 			scripts[SE_LATIN] = true;
 		}
         if (scripts[SE_HAN]) {
 	        if (!strnicmp (((SWModule*)module)->Lang(), "ja", 2)) {
-     			id += UnicodeString(";Kanji-OnRomaji");
+     			id = UnicodeString("Kanji-OnRomaji");
             }
             else {
-       			id += UnicodeString(";Han-Pinyin");
+       			id = UnicodeString("Han-Pinyin");
             }
 			scripts[SE_LATIN] = true;
 		}
 
        		// Inter-Kana and Kana to Latin transliterators
 		if (option == SE_HIRAGANA && scripts[SE_KATAKANA]) {
-			id += UnicodeString(";Katakana-Hiragana");
+			id = UnicodeString("Katakana-Hiragana");
 			scripts[SE_HIRAGANA] = true;
 		}
 		else if (option == SE_KATAKANA && scripts[SE_HIRAGANA]) {
-			id += UnicodeString(";Hiragana-Katakana");
+			id = UnicodeString("Hiragana-Katakana");
 			scripts[SE_KATAKANA] = true;
 		}
 		else {
         		if (scripts[SE_KATAKANA]) {
-	        		id += UnicodeString(";Katakana-Latin");
+	        		id = UnicodeString("Katakana-Latin");
 		        	scripts[SE_LATIN] = true;
         		}
 	        	if (scripts[SE_HIRAGANA]) {
-		        	id += UnicodeString(";Hiragana-Latin");
+		        	id = UnicodeString("Hiragana-Latin");
 			        scripts[SE_LATIN] = true;
         		}
                 }
@@ -285,11 +520,11 @@ char UTF8Transliterator::ProcessText(char *text, int maxlen, const SWKey *key, c
 		}
 		else {
 			if (scripts[SE_HANGUL]) {
-				id += UnicodeString(";Hangul-Latin");
+				id = UnicodeString("Hangul-Latin");
 				scripts[SE_LATIN] = true;
 			}
 			if (scripts[SE_JAMO]) {
-				id += UnicodeString(";Jamo-Latin");
+				id = UnicodeString("Jamo-Latin");
 				scripts[SE_LATIN] = true;
 			}
 		}
@@ -298,100 +533,100 @@ char UTF8Transliterator::ProcessText(char *text, int maxlen, const SWKey *key, c
 		if (option < SE_DEVANAGARI || option > SE_MALAYALAM) {
 			// Indic to Latin
 			if (scripts[SE_TAMIL]) {
-				id += UnicodeString(";Tamil-Latin");
+				id = UnicodeString("Tamil-Latin");
 				scripts[SE_LATIN] = true;
 			}
 			if (scripts[SE_BENGALI]) {
-				id += UnicodeString(";Bengali-Latin");
+				id = UnicodeString("Bengali-Latin");
 				scripts[SE_LATIN] = true;
 			}
 			if (scripts[SE_GURMUKHI]) {
-				id += UnicodeString(";Gurmukhi-Latin");
+				id = UnicodeString("Gurmukhi-Latin");
 				scripts[SE_LATIN] = true;
 			}
 			if (scripts[SE_GUJARATI]) {
-				id += UnicodeString(";Gujarati-Latin");
+				id = UnicodeString("Gujarati-Latin");
 				scripts[SE_LATIN] = true;
 			}
 			if (scripts[SE_ORIYA]) {
-				id += UnicodeString(";Oriya-Latin");
+				id = UnicodeString("Oriya-Latin");
 				scripts[SE_LATIN] = true;
 			}
 			if (scripts[SE_TELUGU]) {
-				id += UnicodeString(";Telugu-Latin");
+				id = UnicodeString("Telugu-Latin");
 				scripts[SE_LATIN] = true;
 			}
 			if (scripts[SE_KANNADA]) {
-				id += UnicodeString(";Kannada-Latin");
+				id = UnicodeString("Kannada-Latin");
 				scripts[SE_LATIN] = true;
 			}
 			if (scripts[SE_MALAYALAM]) {
-				id += UnicodeString(";Malayalam-Latin");
+				id = UnicodeString("Malayalam-Latin");
 				scripts[SE_LATIN] = true;
 			}
 		}
 		else {
 			if (scripts[SE_LATIN]) {
-				id += UnicodeString(";Latin-InterIndic");
+				id = UnicodeString("Latin-InterIndic");
 			}
 			if (scripts[SE_DEVANAGARI]) {
-				id += UnicodeString(";Devanagari-InterIndic");
+				id = UnicodeString("Devanagari-InterIndic");
 			}
 			if (scripts[SE_TAMIL]) {
-				id += UnicodeString(";Tamil-InterIndic");
+				id = UnicodeString("Tamil-InterIndic");
 			}
 			if (scripts[SE_BENGALI]) {
-				id += UnicodeString(";Bengali-InterIndic");
+				id = UnicodeString("Bengali-InterIndic");
 			}
 			if (scripts[SE_GURMUKHI]) {
-				id += UnicodeString(";Gurmurkhi-InterIndic");
+				id = UnicodeString("Gurmurkhi-InterIndic");
 			}
 			if (scripts[SE_GUJARATI]) {
-				id += UnicodeString(";Gujarati-InterIndic");
+				id = UnicodeString("Gujarati-InterIndic");
 			}
 			if (scripts[SE_ORIYA]) {
-				id += UnicodeString(";Oriya-InterIndic");
+				id = UnicodeString("Oriya-InterIndic");
 			}
 			if (scripts[SE_TELUGU]) {
-				id += UnicodeString(";Telugu-InterIndic");
+				id = UnicodeString("Telugu-InterIndic");
 			}
 			if (scripts[SE_KANNADA]) {
-				id += UnicodeString(";Kannada-InterIndic");
+				id = UnicodeString("Kannada-InterIndic");
 			}
 			if (scripts[SE_MALAYALAM]) {
-				id += UnicodeString(";Malayalam-InterIndic");
+				id = UnicodeString("Malayalam-InterIndic");
 			}
 
 			switch(option) {
 			case SE_DEVANAGARI:
-				id += UnicodeString(";InterIndic-Devanagari");
+				id = UnicodeString("InterIndic-Devanagari");
 				break;
 			case SE_TAMIL:
-				id += UnicodeString(";InterIndic-Tamil");
+				id = UnicodeString("InterIndic-Tamil");
 				break;
 			case SE_BENGALI:
-				id += UnicodeString(";InterIndic-Bengali");
+				id = UnicodeString("InterIndic-Bengali");
 				break;
 			case SE_GURMUKHI:
-				id += UnicodeString(";InterIndic-Gurmukhi");
+				id = UnicodeString("InterIndic-Gurmukhi");
 				break;
 			case SE_GUJARATI:
-				id += UnicodeString(";InterIndic-Gujarati");
+				id = UnicodeString("InterIndic-Gujarati");
 				break;
 			case SE_ORIYA:
-				id += UnicodeString(";InterIndic-Oriya");
+				id = UnicodeString("InterIndic-Oriya");
 				break;
 			case SE_TELUGU:
-				id += UnicodeString(";InterIndic-Telugu");
+				id = UnicodeString("InterIndic-Telugu");
 				break;
 			case SE_KANNADA:
-				id += UnicodeString(";InterIndic-Kannada");
+				id = UnicodeString("InterIndic-Kannada");
 				break;
 			case SE_MALAYALAM:
-				id += UnicodeString(";InterIndic-Malayalam");
+				id = UnicodeString("InterIndic-Malayalam");
 				break;
 			default:
-				id += UnicodeString(";InterIndic-Latin");
+				id = UnicodeString("InterIndic-Latin");
 				scripts[SE_LATIN] = true;
 				break;
 			}
@@ -400,71 +635,72 @@ char UTF8Transliterator::ProcessText(char *text, int maxlen, const SWKey *key, c
 		if (scripts[SE_LATIN]) {
                 switch (option) {
                         case SE_GREEK:
-				id += UnicodeString(";Latin-Greek");
+				id = UnicodeString("Latin-Greek");
                                 break;
                         case SE_HEBREW:
-				id += UnicodeString(";Latin-Hebrew");
+				id = UnicodeString("Latin-Hebrew");
                                 break;
                         case SE_CYRILLIC:
-				id += UnicodeString(";Latin-Cyrillic");
+				id = UnicodeString("Latin-Cyrillic");
                                 break;
                         case SE_ARABIC:
-				id += UnicodeString(";Latin-Arabic");
+				id = UnicodeString("Latin-Arabic");
                                 break;
                         case SE_SYRIAC:
-				id += UnicodeString(";Latin-Syriac");
+				id = UnicodeString("Latin-Syriac");
                                 break;
                         case SE_THAI:
-				id += UnicodeString(";Latin-Thai");
+				id = UnicodeString("Latin-Thai");
                                 break;
                         case SE_GEORGIAN:
-				id += UnicodeString(";Latin-Georgian");
+				id = UnicodeString("Latin-Georgian");
                                 break;
                         case SE_ARMENIAN:
-				id += UnicodeString(";Latin-Armenian");
+				id = UnicodeString("Latin-Armenian");
                                 break;
                         case SE_ETHIOPIC:
-				id += UnicodeString(";Latin-Ethiopic");
+				id = UnicodeString("Latin-Ethiopic");
                                 break;
                         case SE_GOTHIC:
-				id += UnicodeString(";Latin-Gothic");
+				id = UnicodeString("Latin-Gothic");
                                 break;
                         case SE_UGARITIC:
-				id += UnicodeString(";Latin-Ugaritic");
+				id = UnicodeString("Latin-Ugaritic");
                                 break;
                         case SE_COPTIC:
-				id += UnicodeString(";Latin-Coptic");
+				id = UnicodeString("Latin-Coptic");
                                 break;
                         case SE_KATAKANA:
-				id += UnicodeString(";Latin-Katakana");
+				id = UnicodeString("Latin-Katakana");
                                 break;
                         case SE_HIRAGANA:
-				id += UnicodeString(";Latin-Hiragana");
+				id = UnicodeString("Latin-Hiragana");
                                 break;
                         case SE_JAMO:
-				id += UnicodeString(";Latin-Jamo");
+				id = UnicodeString("Latin-Jamo");
                                 break;
                         case SE_HANGUL:
-				id += UnicodeString(";Latin-Hangul");
+				id = UnicodeString("Latin-Hangul");
                                 break;
                         }
                 }
 
                 if (option == SE_BASICLATIN) {
-                        id += UnicodeString(";Any-Latin1");
+                        id = UnicodeString("Any-Latin1");
                 }
-                                
+                UnicodeString postid;                
                 if (noNFC) {
-                        id += UnicodeString(";NFD");
+                        postid = UnicodeString(";NFD");
                 } else {
-                        id += UnicodeString(";NFC");
+                        postid = UnicodeString(";NFC");
                 }
 
-                UParseError perr;
+                //UParseError perr;
 
                 err = U_ZERO_ERROR;
-                Transliterator * trans = Transliterator::createInstance(id, UTRANS_FORWARD, perr, err);
-                if (trans) {
+                //Transliterator * trans = Transliterator::createInstance(id, UTRANS_FORWARD, perr, err);
+				Transliterator * trans = createTrans(preid, id, postid, UTRANS_FORWARD, err);
+                if (trans && !U_FAILURE(err)) {
                         UnicodeString target = UnicodeString(source);
                         trans->transliterate(target);
                         len = ucnv_fromUChars(conv, text, maxlen, target.getBuffer(), target.length(), &err);
@@ -477,3 +713,6 @@ char UTF8Transliterator::ProcessText(char *text, int maxlen, const SWKey *key, c
 	return 0;
 }
 #endif
+
+
+
