@@ -88,15 +88,11 @@ char RawLD::getEntry(long away)
 
 	strongsPad(buf);
 
-	*entrybuf = 0;
 	if (!(retval = findoffset(buf, &start, &size, away))) {
+		readtext(start, &size, &idxbuf, &entrybuf);
+		rawFilter(entrybuf, size, 0);	// hack, decipher
+		rawFilter(entrybuf, size, key);
 		entrySize = size;        // support getEntrySize call
-		if (entrybuf)
-			delete [] entrybuf;
-		entrybuf = new char [ ++size * FILTERPAD ];
-		idxbuf   = new char [ size * FILTERPAD ];
-
-		gettext(start, size + 1, idxbuf, entrybuf);
 		if (!key->Persist())			// If we have our own key
 			*key = idxbuf;				// reset it to entry index buffer
 
@@ -104,6 +100,8 @@ char RawLD::getEntry(long away)
 		delete [] idxbuf;
 	}
 	else {
+		if (entrybuf)
+			delete [] entrybuf;
 		entrybuf = new char [ 5 ];
 		*entrybuf = 0;
 	}
@@ -114,82 +112,55 @@ char RawLD::getEntry(long away)
 
 
 /******************************************************************************
- * RawLD::operator char *	- Returns the correct entry when char * cast
+ * RawLD::getRawEntry	- Returns the correct entry when char * cast
  *							is requested
  *
  * RET: string buffer with entry
  */
 
 char *RawLD::getRawEntry() {
-	if (!getEntry() && !isUnicode()) {
-		preptext(entrybuf);
+
+	char ret = getEntry();
+	if (!ret) {
+		if (!isUnicode())
+			preptext(entrybuf);
 	}
+	else error = ret;
 
 	return entrybuf;
 }
 
 
 /******************************************************************************
- * RawLD::operator +=	- Increments module key a number of entries
+ * RawLD::increment	- Increments module key a number of entries
  *
  * ENT:	increment	- Number of entries to jump forward
  *
  * RET: *this
  */
 
-SWModule &RawLD::operator +=(int increment)
-{
+void RawLD::increment(int steps) {
 	char tmperror;
 
 	if (key->Traversable()) {
-		*key += increment;
+		*key += steps;
 		error = key->Error();
-		increment = 0;
+		steps = 0;
 	}
 	
-	tmperror = (getEntry(increment)) ? KEYERR_OUTOFBOUNDS : 0;
+	tmperror = (getEntry(steps)) ? KEYERR_OUTOFBOUNDS : 0;
 	error = (error)?error:tmperror;
 	*key = entkeytxt;
-	return *this;
 }
 
 
-/******************************************************************************
- * RawLD::operator =(SW_POSITION)	- Positions this key if applicable
- */
-
-SWModule &RawLD::operator =(SW_POSITION p)
-{
-	if (!key->Traversable()) {
-		switch (p) {
-		case POS_TOP:
-			*key = "";
-			break;
-		case POS_BOTTOM:
-			*key = "zzzzzzzzz";
-			break;
-		} 
-	}
-	else	*key = p;
-	return *this;
-}
-
-
-SWModule &RawLD::setentry(const char *inbuf, long len) {
+void RawLD::setEntry(const char *inbuf, long len) {
 	settext(*key, inbuf, len);
-
-	return *this;
-}
-
-SWModule &RawLD::operator <<(const char *inbuf) {
-	return setentry(inbuf, 0);
 }
 
 
-SWModule &RawLD::operator <<(const SWKey *inkey) {
+void RawLD::linkEntry(const SWKey *inkey) {
 	linkentry(*key, *inkey);
-
-	return *this;
 }
 
 
