@@ -90,13 +90,10 @@ char RawLD4::getEntry(long away)
 
 	*entrybuf = 0;
 	if (!(retval = findoffset(buf, &start, &size, away))) {
+		readtext(start, &size, &idxbuf, &entrybuf);
+		rawFilter(entrybuf, size, 0);	// hack, decipher
+		rawFilter(entrybuf, size, key);
 		entrySize = size;        // support getEntrySize call
-		if (entrybuf)
-			delete [] entrybuf;
-		entrybuf = new char [ ++size * FILTERPAD ];
-		idxbuf   = new char [ size * FILTERPAD ];
-
-		gettext(start, size, idxbuf, entrybuf);
 		if (!key->Persist())			// If we have our own key
 			*key = idxbuf;				// reset it to entry index buffer
 
@@ -114,82 +111,55 @@ char RawLD4::getEntry(long away)
 
 
 /******************************************************************************
- * RawLD4::operator char *	- Returns the correct entry when char * cast
+ * RawLD4::getRawEntry	- Returns the correct entry when char * cast
  *							is requested
  *
  * RET: string buffer with entry
  */
 
 char *RawLD4::getRawEntry() {
-	if (!getEntry() && !isUnicode()) {
-		preptext(entrybuf);
+
+	char ret = getEntry();
+	if (!ret) {
+		if (!isUnicode())
+			preptext(entrybuf);
 	}
+	else error = ret;
 
 	return entrybuf;
 }
 
 
 /******************************************************************************
- * RawLD4::operator +=	- Increments module key a number of entries
+ * RawLD4::increment	- Increments module key a number of entries
  *
  * ENT:	increment	- Number of entries to jump forward
  *
  * RET: *this
  */
 
-SWModule &RawLD4::operator +=(int increment)
-{
+void RawLD4::increment(int steps) {
 	char tmperror;
 
 	if (key->Traversable()) {
-		*key += increment;
+		*key += steps;
 		error = key->Error();
-		increment = 0;
+		steps = 0;
 	}
 	
-	tmperror = (getEntry(increment)) ? KEYERR_OUTOFBOUNDS : 0;
+	tmperror = (getEntry(steps)) ? KEYERR_OUTOFBOUNDS : 0;
 	error = (error)?error:tmperror;
 	*key = entkeytxt;
-	return *this;
 }
 
 
-/******************************************************************************
- * RawLD4::operator =(SW_POSITION)	- Positions this key if applicable
- */
-
-SWModule &RawLD4::operator =(SW_POSITION p)
-{
-	if (!key->Traversable()) {
-		switch (p) {
-		case POS_TOP:
-			*key = "";
-			break;
-		case POS_BOTTOM:
-			*key = "zzzzzzzzz";
-			break;
-		} 
-	}
-	else	*key = p;
-	return *this;
+void RawLD4::setEntry(const char *inbuf, long len) {
+	setText(*key, inbuf, len);
 }
 
 
-SWModule &RawLD4::setentry(const char *inbuf, long len) {
-	settext(*key, inbuf, len);
-
-	return *this;
-}
-
-SWModule &RawLD4::operator <<(const char *inbuf) {
-	return setentry(inbuf, 0);
-}
-
-
-SWModule &RawLD4::operator <<(const SWKey *inkey) {
+void RawLD4::linkEntry(const SWKey *inkey) {
 	linkentry(*key, *inkey);
-
-	return *this;
 }
 
 
@@ -200,5 +170,5 @@ SWModule &RawLD4::operator <<(const SWKey *inkey) {
  */
 
 void RawLD4::deleteEntry() {
-	settext(*key, "");
+	setText(*key, "");
 }
