@@ -11,7 +11,7 @@
 #include <swfilter.h>
 #include <versekey.h>	// KLUDGE for Search
 #ifndef _MSC_VER
-#include <iostream.h>
+#include <iostream>
 #endif
 
 SWDisplay SWModule::rawdisp;
@@ -28,8 +28,7 @@ void SWModule::nullPercent(char percent, void *percentUserData) {}
  *	unicode  - if this module is unicode
  */
 
-SWModule::SWModule(const char *imodname, const char *imoddesc, SWDisplay *idisp, char *imodtype, SWTextEncoding encoding, SWTextDirection direction, SWTextMarkup markup, const char* imodlang)
-{
+SWModule::SWModule(const char *imodname, const char *imoddesc, SWDisplay *idisp, char *imodtype, SWTextEncoding encoding, SWTextDirection direction, SWTextMarkup markup, const char* imodlang) {
 	key       = CreateKey();
 	entrybuf  = new char [1];
 	*entrybuf = 0;
@@ -257,20 +256,27 @@ char SWModule::Display()
 
 
 /******************************************************************************
- * SWModule::SetKey - Sets a key to this module for position to a particular
- *			record or set of records
+ * SWModule::getKey - Gets the key from this module that points to the position
+ *			record
+ *
+ * RET:	key object
+ */
+
+SWKey *SWModule::getKey() const {
+	return key;
+}
+
+
+/******************************************************************************
+ * SWModule::setKey - Sets a key to this module for position to a particular
+ *			record
  *
  * ENT:	ikey - key with which to set this module
  *
  * RET:	error status
  */
 
-char SWModule::SetKey(const SWKey &ikey) {
-	return SetKey(&ikey);
-}
-
-char SWModule::SetKey(const SWKey *ikey)
-{
+char SWModule::setKey(const SWKey *ikey) {
 	SWKey *oldKey = 0;
 
 	if (key) {
@@ -292,33 +298,14 @@ char SWModule::SetKey(const SWKey *ikey)
 
 
 /******************************************************************************
- * SWModule::KeyText - Sets/gets module KeyText
- *
- * ENT:	ikeytext - value which to set keytext
- *		[0] - only get
- *
- * RET:	pointer to keytext
- */
-
-const char *SWModule::KeyText(const char *ikeytext)
-{
-	if (ikeytext)
-		SetKey(ikeytext);
-
-	return *key;
-}
-
-
-/******************************************************************************
- * SWModule::operator =(SW_POSITION)	- Positions this modules to an entry
+ * SWModule::setPosition(SW_POSITION)	- Positions this modules to an entry
  *
  * ENT:	p	- position (e.g. TOP, BOTTOM)
  *
  * RET: *this
  */
 
-SWModule &SWModule::operator =(SW_POSITION p)
-{
+void SWModule::setPosition(SW_POSITION p) {
 	*key = p;
 	char saveError = key->Error();
 
@@ -335,41 +322,34 @@ SWModule &SWModule::operator =(SW_POSITION p)
 	}
 
 	error = saveError;
-	return *this;
 }
 
 
 /******************************************************************************
- * SWModule::operator +=	- Increments module key a number of entries
+ * SWModule::increment	- Increments module key a number of entries
  *
  * ENT:	increment	- Number of entries to jump forward
  *
  * RET: *this
  */
 
-SWModule &SWModule::operator +=(int increment)
-{
-	(*key) += increment;
+void SWModule::increment(int steps) {
+	(*key) += steps;
 	error = key->Error();
-
-	return *this;
 }
 
 
 /******************************************************************************
- * SWModule::operator -=	- Decrements module key a number of entries
+ * SWModule::decrement	- Decrements module key a number of entries
  *
  * ENT:	decrement	- Number of entries to jump backward
  *
  * RET: *this
  */
 
-SWModule &SWModule::operator -=(int increment)
-{
-	(*key) -= increment;
+void SWModule::decrement(int steps) {
+	(*key) -= steps;
 	error = key->Error();
-
-	return *this;
 }
 
 
@@ -414,7 +394,7 @@ ListKey &SWModule::Search(const char *istr, int searchType, int flags, SWKey *sc
 	searchkey = (scope)?scope->clone():(key->Persist())?key->clone():0;
 	if (searchkey) {
 		searchkey->Persist(1);
-		SetKey(*searchkey);
+		setKey(*searchkey);
 	}
 
 	(*percent)(perc, percentUserData);
@@ -481,12 +461,12 @@ ListKey &SWModule::Search(const char *istr, int searchType, int flags, SWKey *sc
 		}
 		else if (newperc < perc) {
 #ifndef _MSC_VER
-			cerr << "Serious error: new percentage complete is less than previous value\n";
-			cerr << "using vk? " << ((vkcheck)?"yes":"no") << "\n";
-			cerr << "index: " << ((vkcheck)?vkcheck->NewIndex():key->Index()) << "\n";
-			cerr << "highIndex: " << highIndex << "\n";
-			cerr << "newperc ==" << (int)newperc << "%" << "is smaller than\n";
-			cerr << "perc == "  << (int )perc << "% \n";
+			std::cerr << "Serious error: new percentage complete is less than previous value\n";
+			std::cerr << "using vk? " << ((vkcheck)?"yes":"no") << "\n";
+			std::cerr << "index: " << ((vkcheck)?vkcheck->NewIndex():key->Index()) << "\n";
+			std::cerr << "highIndex: " << highIndex << "\n";
+			std::cerr << "newperc ==" << (int)newperc << "%" << "is smaller than\n";
+			std::cerr << "perc == "  << (int )perc << "% \n";
 #endif
 		}
 		if (searchType >= 0) {
@@ -528,7 +508,7 @@ ListKey &SWModule::Search(const char *istr, int searchType, int flags, SWKey *sc
 		free(wordBuf);
 	}
 
-	SetKey(*savekey);
+	setKey(*savekey);
 
 	if (!savekey->Persist())
 		delete savekey;
@@ -574,9 +554,7 @@ const char *SWModule::StripText(char *buf, int len)
 	static char *null = "";
 
 	if (tmpbuf) {
-		unsigned long size = (len < 0) ? getEntrySize() * FILTERPAD : len;
-          if (size < 0)
-          	size = strlen(tmpbuf);
+		unsigned long size = (len < 0) ? ((getEntrySize()<0) ? strlen(tmpbuf) : getEntrySize()) * FILTERPAD : len;
 		if (size > 0) {
 			key = (SWKey *)*this;
 
@@ -616,11 +594,11 @@ const char *SWModule::StripText(char *buf, int len)
 	}
 	else	savekey = key;
 
-	SetKey(*tmpKey);
+	setKey(*tmpKey);
 
 	retVal = RenderText();
 
-	SetKey(*savekey);
+	setKey(*savekey);
 
 	if (!savekey->Persist())
 		delete savekey;
@@ -648,11 +626,11 @@ const char *SWModule::StripText(SWKey *tmpKey)
 	}
 	else	savekey = key;
 
-	SetKey(*tmpKey);
+	setKey(*tmpKey);
 
 	retVal = StripText();
 
-	SetKey(*savekey);
+	setKey(*savekey);
 
 	if (!savekey->Persist())
 		delete savekey;
@@ -661,11 +639,6 @@ const char *SWModule::StripText(SWKey *tmpKey)
 }
 
 
-SWModule::operator const char*() {
-	return RenderText();
-}
-
-
 const char *SWModule::getConfigEntry(const char *key) const {
 	ConfigEntMap::iterator it = config->find(key);
 	return (it != config->end()) ? it->second.c_str() : 0;
