@@ -14,7 +14,6 @@
 #include <unistd.h>
 #endif
 
-#include <iostream.h>
 #include <string.h>
 #include <utilfuns.h>
 //#include <rawverse.h>
@@ -61,69 +60,22 @@ zText::~zText()
 
 char *zText::getRawEntry()
 {
-/*
-	long  start;
-	unsigned long size;
-	unsigned long destsize;
-	char *tmpbuf;
-	char *dest;
-	VerseKey *lkey = (VerseKey *) SWModule::key;
-	char sizebuf[3];
-
-	lkey->Verse(0);
-	if (chapcache != lkey->Index()) {
-		findoffset(lkey->Testament(), lkey->Index(), &start, &((unsigned short) size));
-		gettext(lkey->Testament(), start, 3, sizebuf);
-		memcpy(&size, sizebuf, 2);
-		tmpbuf = new char [ size + 1 ];
-		gettext(lkey->Testament(), start + 2, size + 1 , tmpbuf);
-		//zBuf(&size, tmpbuf);
-		dest = new char [ (size*4) + 1 ];
-		uncompress((Bytef *)dest, &destsize, (Bytef *) tmpbuf, size);
-		chapcache = lkey->Index();
-		delete [] tmpbuf;
-	}
-
-	//findoffset(key->Testament(), key->Index(), &start, &size);
-	findoffset(lkey->Testament(), lkey->Index(), &start, &((unsigned short) size));
-
-	if (versebuf)
-		delete [] versebuf;
-	versebuf = new char [ size + 1 ];
-	//memcpy(versebuf, Buf(), size);
-	memcpy(versebuf, dest, destsize);
-	delete [] dest;
-
-	preptext(versebuf);
-
-	return versebuf;
-*/
-
 	long  start = 0;
 	unsigned short size = 0;
 	VerseKey *key = 0;
 
-	//printf ("zText char *\n");
-
 	// see if we have a VerseKey * or decendant
-#ifndef _WIN32_WCE
 	try {
-#endif
 		key = SWDYNAMIC_CAST(VerseKey, this->key);
-#ifndef _WIN32_WCE
 	}
 	catch ( ... ) {}
-#endif
 	// if we don't have a VerseKey * decendant, create our own
 	if (!key)
 		key = new VerseKey(this->key);
 
-	//printf ("checking cache\n");
-	//printf ("finding offset\n");
 	findoffset(key->Testament(), key->Index(), &start, &size);
 	entrySize = size;        // support getEntrySize call
 
-	//printf ("deleting previous buffer\n");
 	unsigned long newsize = (size + 2) * FILTERPAD;
 	if (newsize > entrybufallocsize) {
 		if (entrybuf)
@@ -133,22 +85,17 @@ char *zText::getRawEntry()
 	}
 	*entrybuf = 0;
 
-	//printf ("getting text\n");
-	swgettext(key->Testament(), start, (size + 2), entrybuf);
-	//printf ("got text\n");
+	zreadtext(key->Testament(), start, (size + 2), entrybuf);
 
 	rawFilter(entrybuf, size, key);
 
-	//printf ("preparing text\n");
-        if (!isUnicode())
+	if (!isUnicode())
 		preptext(entrybuf);
 
 	if (this->key != key) // free our key if we created a VerseKey
 		delete key;
 
-	//printf ("returning text\n");
 	return entrybuf;
-
 }
 
 
@@ -171,17 +118,13 @@ bool zText::sameBlock(VerseKey *k1, VerseKey *k2) {
 }
 
 
-SWModule &zText::setentry(const char *inbuf, long len) {
+void zText::setEntry(const char *inbuf, long len) {
 	VerseKey *key = 0;
 	// see if we have a VerseKey * or decendant
-#ifndef _WIN32_WCE
 	try {
-#endif
 		key = SWDYNAMIC_CAST(VerseKey, this->key);
-#ifndef _WIN32_WCE
 	}
 	catch ( ... ) {}
-#endif
 	// if we don't have a VerseKey * decendant, create our own
 	if (!key)
 		key = new VerseKey(this->key);
@@ -201,41 +144,27 @@ SWModule &zText::setentry(const char *inbuf, long len) {
 
 	if (this->key != key) // free our key if we created a VerseKey
 		delete key;
-
-	return *this;
-}
-
-SWModule &zText::operator <<(const char *inbuf) {
-        return setentry(inbuf, 0);
 }
 
 
-SWModule &zText::operator <<(const SWKey *inkey) {
+void zText::linkEntry(const SWKey *inkey) {
 	VerseKey *destkey = 0;
 	const VerseKey *srckey = 0;
 	// see if we have a VerseKey * or decendant
-#ifndef _WIN32_WCE
 	try {
-#endif
 		destkey = SWDYNAMIC_CAST(VerseKey, this->key);
-#ifndef _WIN32_WCE
 	}
 	catch ( ... ) {}
-#endif
 	// if we don't have a VerseKey * decendant, create our own
 	if (!destkey)
 		destkey = new VerseKey(this->key);
 
 	// see if we have a VerseKey * or decendant
-#ifndef _WIN32_WCE
 	try {
-#endif
 		srckey = (const VerseKey *) SWDYNAMIC_CAST(VerseKey, inkey);
-#ifndef _WIN32_WCE
 	}
 	catch ( ... ) {
 	}
-#endif
 	// if we don't have a VerseKey * decendant, create our own
 	if (!srckey)
 		srckey = new VerseKey(inkey);
@@ -247,29 +176,22 @@ SWModule &zText::operator <<(const SWKey *inkey) {
 
 	if (inkey != srckey) // free our key if we created a VerseKey
 		delete srckey;
-
-	return *this;
 }
 
 
 /******************************************************************************
  * zFiles::deleteEntry	- deletes this entry
  *
- * RET: *this
  */
 
 void zText::deleteEntry() {
 
 	VerseKey *key = 0;
 
-#ifndef _WIN32_WCE
 	try {
-#endif
 		key = SWDYNAMIC_CAST(VerseKey, this->key);
-#ifndef _WIN32_WCE
 	}
 	catch ( ... ) {}
-#endif
 	if (!key)
 		key = new VerseKey(this->key);
 
@@ -281,49 +203,39 @@ void zText::deleteEntry() {
 
 
 /******************************************************************************
- * zText::operator +=	- Increments module key a number of entries
+ * zText::increment	- Increments module key a number of entries
  *
  * ENT:	increment	- Number of entries to jump forward
  *
- * RET: *this
  */
 
-SWModule &zText::operator +=(int increment)
-{
+void zText::increment(int steps) {
 	long  start;
 	unsigned short size;
 	VerseKey *tmpkey = 0;
 
-#ifndef _WIN32_WCE
 	try {
-#endif
 		tmpkey = SWDYNAMIC_CAST(VerseKey, key);
-#ifndef _WIN32_WCE
 	}
 	catch ( ... ) {}
-#endif
 	if (!tmpkey)
 		tmpkey = new VerseKey(key);
 
 	findoffset(tmpkey->Testament(), tmpkey->Index(), &start, &size);
 
 	SWKey lastgood = *tmpkey;
-	while (increment) {
+	while (steps) {
 		long laststart = start;
 		unsigned short lastsize = size;
 		SWKey lasttry = *tmpkey;
-		(increment > 0) ? (*key)++ : (*key)--;
+		(steps > 0) ? (*key)++ : (*key)--;
 		if (tmpkey != key)
 			delete tmpkey;
 		tmpkey = 0;
-#ifndef _WIN32_WCE
 		try {
-#endif
 			tmpkey = SWDYNAMIC_CAST(VerseKey, key);
-#ifndef _WIN32_WCE
 		}
 		catch ( ... ) {}
-#endif
 		if (!tmpkey)
 			tmpkey = new VerseKey(key);
 
@@ -333,8 +245,12 @@ SWModule &zText::operator +=(int increment)
 		}
 		long index = tmpkey->Index();
 		findoffset(tmpkey->Testament(), index, &start, &size);
-		if ((((laststart != start) || (lastsize != size))||(!skipConsecutiveLinks)) && (start >= 0) && (size)) {
-			increment += (increment < 0) ? 1 : -1;
+
+		if (
+			(((laststart != start) || (lastsize != size))	// we're a different entry
+				&& (start > 0) && (size))	// and we actually have a size
+				||(!skipConsecutiveLinks)) {	// or we don't want to skip consecutive links
+			steps += (steps < 0) ? 1 : -1;
 			lastgood = *tmpkey;
 		}
 	}
@@ -342,6 +258,4 @@ SWModule &zText::operator +=(int increment)
 
 	if (tmpkey != key)
 		delete tmpkey;
-
-	return *this;
 }
