@@ -2,6 +2,17 @@
 #include <utilstr.h>
 #include <ctype.h>
 
+#ifdef _ICU_
+#include <unicode/utypes.h>
+#include <unicode/ucnv.h>
+#include <unicode/ustring.h>
+#include <unicode/uchar.h>
+
+#include <unicode/unistr.h>
+#include <unicode/translit.h>
+
+#endif
+
 /******************************************************************************
  * stdstr - Sets/gets a string
  *
@@ -17,7 +28,7 @@ char *stdstr(char **ipstr, const char *istr) {
 		if (*ipstr)
 			delete [] *ipstr;
 		int len = strlen(istr) + 1;
-		*ipstr = new char [ len ];
+		*ipstr = new char [ len*2 ];	// *2 buffer for unicode manipulations
 		memcpy(*ipstr, istr, len);
 	}
 	return *ipstr;
@@ -41,8 +52,8 @@ char *strstrip(char *istr) {
 		return istr;
 	rtmp = istr + (len - 1);
 	
-	while (*rtmp == ' ') *(rtmp--) = 0;
-	while (*tmp == ' ') tmp++;
+	while ((rtmp > istr)&&((*rtmp == ' ')||(*rtmp == '\t')||(*rtmp == 10)||(*rtmp == 13))) *(rtmp--) = 0;
+	while ((*tmp == ' ')||(*tmp == '\t')||(*tmp == 10)||(*tmp == 13)) tmp++;
 	memmove(istr, tmp, (rtmp - tmp) + 1);
 	istr[(rtmp - tmp) + 1] = 0;
 
@@ -95,18 +106,17 @@ const char *stristr(const char *s1, const char *s2) {
  */
 
 const char strnicmp(const char *s1, const char *s2, int len) {
-
-     int tLen = strlen(s2);
-     int cLen = strlen(s1);
-     char diff;
-     int i;
-     for (i = 0; ((i < len) && (i < tLen) && (i < cLen)); i++) {
-     	if ((diff = SW_toupper(*s1) - SW_toupper(*s2)))
-          	return diff;
+	int tLen = strlen(s2);
+	int cLen = strlen(s1);
+	char diff;
+	int i;
+	for (i = 0; ((i < len) && (i < tLen) && (i < cLen)); i++) {
+		if ((diff = SW_toupper(*s1) - SW_toupper(*s2)))
+			return diff;
 	s1++;
 	s2++;
-     }
-     return (i < len) ? cLen - tLen : 0;
+	}
+	return (i < len) ? cLen - tLen : 0;
 }
 
 /******************************************************************************
@@ -145,8 +155,44 @@ unsigned int strlenw(const char *s1) {
 
 char *toupperstr(char *buf) {
 	char *ret = buf;
+
 	while (*buf)
 		*buf = SW_toupper(*buf++);
 
 	return ret;
 }
+
+
+/******************************************************************************
+ * toupperstr - converts a string to uppercase string
+ *
+ * ENT:	target - string to convert
+ *
+ * RET:	target
+ */
+
+char *toupperstr_utf8(char *buf) {
+	char *ret = buf;
+
+#ifndef _ICU_
+	// try to decide if it's worth trying to toupper.  Do we have more
+	// characters that are probably lower latin than not?
+	long performOp = 0;
+	for (const char *ch = buf; *ch; ch++)
+		performOp += (*ch > 0) ? 1 : -1;
+
+	if (performOp) {
+		while (*buf)
+			*buf = SW_toupper(*buf++);
+	}
+#else
+		UErrorCode err = U_ZERO_ERROR;
+		UConverter *conv = ucnv_open("UTF-8", &err);
+		UnicodeString str(buf, -1, conv, err);
+		UnicodeString ustr = str.toUpper();
+		ustr.extract(ret, strlen(ret)*2, conv, err);
+		ucnv_close(conv);
+#endif
+
+	return ret;
+}
