@@ -1,5 +1,5 @@
 #include <swmgr.h>
-#include <iostream.h>
+#include <iostream>
 #include <versekey.h>
 
 int main(int argc, char **argv) {
@@ -10,9 +10,9 @@ int main(int argc, char **argv) {
 	if (bbe) {
 		VerseKey vk;
 		vk.Persist(1);
-		bbe->SetKey(vk);
+		bbe->setKey(vk);
 		for (; !bbe->Error(); (*bbe)++ ) {
-			cout << vk.NewIndex() << endl; 
+			std::cout << vk.NewIndex() << std::endl; 
 		}
 	}
 	return 0;
