@@ -1,5 +1,5 @@
 #include <stdio.h>
-#include <iostream.h>
+#include <iostream>
 #include <versekey.h>
 #include <rawtext.h>
 #include <rawcom.h>
@@ -24,32 +24,32 @@ int main(int argc, char **argv)
 		bla = "James    1:19";
 	else	bla = argv[1];
 
-	cout << "\n loop++; (.Index(Index()+1))\n";
+	std::cout << "\n loop++; (.Index(Index()+1))\n";
 
 	max = (argc < 3) ? 10 : atoi(argv[2]);
 
 	for (loop = 0; loop < max; loop++, bla++) {
 		index = bla.Index();
-		cout << (const char *)bla << "(" << index << ")";
+		std::cout << (const char *)bla << "(" << index << ")";
 		bla.Index(index+1);
-		cout << "-> " << (const char *)bla << "\n";
+		std::cout << "-> " << (const char *)bla << "\n";
 	}
 
-	cout << "-----------------\n";
-	cout << "\n loop--; (.Index(Index()-1))\n";
+	std::cout << "-----------------\n";
+	std::cout << "\n loop--; (.Index(Index()-1))\n";
 	if (argc < 2) 
 		bla = "James    1:19";
 	else	bla = argv[1];
 
 	for (loop = max; loop; loop--, bla--) {
 		index = bla.Index();
-		cout << (const char *)bla << "(" << index << ")";
+		std::cout << (const char *)bla << "(" << index << ")";
 		bla.Index(index-1);
-		cout << "-> " << (const char *)bla << "\n";
+		std::cout << "-> " << (const char *)bla << "\n";
 	}
 
-	cout << "-----------------\n";
-	cout << "--------- No Headings --------\n";
+	std::cout << "-----------------\n";
+	std::cout << "--------- No Headings --------\n";
 
 	if (argc < 2) 
 		bla = "Matthew  1:5";
@@ -57,10 +57,10 @@ int main(int argc, char **argv)
 
 	for (loop = max; loop; loop--, bla--) {
 		index = bla.Index();
-		cout << (const char *)bla << "(" << index << ")\n";
+		std::cout << (const char *)bla << "(" << index << ")\n";
 	}
 
-	cout << "-----------------\n";
+	std::cout << "-----------------\n";
 
 	if (argc < 2) 
 		bla = "Genesis  1:5";
@@ -68,10 +68,10 @@ int main(int argc, char **argv)
 
 	for (loop = max; loop; loop--, bla--) {
 		index = bla.Index();
-		cout << (const char *)bla << "(" << index << ")\n";
+		std::cout << (const char *)bla << "(" << index << ")\n";
 	}
 
-	cout << "-----------------\n";
+	std::cout << "-----------------\n";
 
 	if (argc < 2) 
 		bla = "Malachi  4:2";
@@ -79,10 +79,10 @@ int main(int argc, char **argv)
 
 	for (loop = max; loop; loop--, bla++) {
 		index = bla.Index();
-		cout << (const char *)bla << "(" << index << ")\n";
+		std::cout << (const char *)bla << "(" << index << ")\n";
 	}
 
-	cout << "-----------------\n";
+	std::cout << "-----------------\n";
 
 	if (argc < 2) 
 		bla = "Revelation of John  22:17";
@@ -90,12 +90,12 @@ int main(int argc, char **argv)
 
 	for (loop = max; loop; loop--, bla++) {
 		index = bla.Index();
-		cout << (const char *)bla << "(" << index << ")\n";
+		std::cout << (const char *)bla << "(" << index << ")\n";
 	}
 
 
-	cout << "-----------------\n";
-	cout << "-------- Headings ---------\n";
+	std::cout << "-----------------\n";
+	std::cout << "-------- Headings ---------\n";
 
 	bla.Headings(1);
 
@@ -105,10 +105,10 @@ int main(int argc, char **argv)
 
 	for (loop = max; loop; loop--, bla--) {
 		index = bla.Index();
-		cout << (const char *)bla << "(" << index << ")\n";
+		std::cout << (const char *)bla << "(" << index << ")\n";
 	}
 
-	cout << "-----------------\n";
+	std::cout << "-----------------\n";
 
 	if (argc < 2) 
 		bla = "Genesis  1:5";
@@ -116,10 +116,10 @@ int main(int argc, char **argv)
 
 	for (loop = max; loop; loop--, bla--) {
 		index = bla.Index();
-		cout << (const char *)bla << "(" << index << ")\n";
+		std::cout << (const char *)bla << "(" << index << ")\n";
 	}
 
-	cout << "-----------------\n";
+	std::cout << "-----------------\n";
 
 	if (argc < 2) 
 		bla = "Malachi  4:2";
@@ -127,10 +127,10 @@ int main(int argc, char **argv)
 
 	for (loop = max; loop; loop--, bla++) {
 		index = bla.Index();
-		cout << (const char *)bla << "(" << index << ")\n";
+		std::cout << (const char *)bla << "(" << index << ")\n";
 	}
 
-	cout << "-----------------\n";
+	std::cout << "-----------------\n";
 
 	if (argc < 2) 
 		bla = "Revelation of John  22:17";
@@ -138,32 +138,32 @@ int main(int argc, char **argv)
 
 	for (loop = max; loop; loop--, bla++) {
 		index = bla.Index();
-		cout << (const char *)bla << "(" << index << ")\n";
+		std::cout << (const char *)bla << "(" << index << ")\n";
 	}
 
-	cout << "\n\n";
+	std::cout << "\n\n";
 
-	cout << "-------- Error Check ------------\n\n";
+	std::cout << "-------- Error Check ------------\n\n";
 	bla = "Revelation of John 23:19";
-	cout << "bla = \"Revelation of John 23:19\"\n";
-	cout << "(const char *)bla = " << (const char *)bla << "\n";
-	cout << "bla.Error() = " << (int)bla.Error() << " \n";
-	cout << "bla++ \n";
+	std::cout << "bla = \"Revelation of John 23:19\"\n";
+	std::cout << "(const char *)bla = " << (const char *)bla << "\n";
+	std::cout << "bla.Error() = " << (int)bla.Error() << " \n";
+	std::cout << "bla++ \n";
 	bla++;
-	cout << "bla.Error() = " << (int)bla.Error() << " \n";
+	std::cout << "bla.Error() = " << (int)bla.Error() << " \n";
 
 	bla.Headings(0);
 	for (bla = BOTTOM; !bla.Error(); bla.Book(bla.Book()-1))
-		cout << (const char *)bla << "\n";
+		std::cout << (const char *)bla << "\n";
 	bla.Testament(1);
 	bla = BOTTOM;
-	cout << bla.Index() << "\n";
-	cout << bla.NewIndex() << "\n";
-	cout << bla << "\n";
+	std::cout << bla.Index() << "\n";
+	std::cout << bla.NewIndex() << "\n";
+	std::cout << bla << "\n";
 	bla.Testament(2);
 	bla = BOTTOM;
-	cout << bla.Index() << "\n";
-	cout << bla.NewIndex() << "\n";
-	cout << bla << "\n";
+	std::cout << bla.Index() << "\n";
+	std::cout << bla.NewIndex() << "\n";
+	std::cout << bla << "\n";
 	return 0;
 }
