@@ -1,8 +1,8 @@
 #!/bin/sh
 
-./configure --prefix=/usr \
-	--enable-debug --disable-shared \
-	--without-conf --sysconfdir=/etc
+CPPFLAGS=-DUSBINARY ./configure --prefix=/usr \
+	--disable-shared --enable-debug --without-conf --sysconfdir=/etc --with-vcl \
+	$*
 
 echo ""
 echo ""
