@@ -15,7 +15,6 @@
 #include <rawld4.h>
 #include <zld.h>
 #include <zipcomprs.h>
-#include <iostream.h>
 
 
 #ifndef O_BINARY
@@ -59,7 +58,7 @@ int main(int argc, char **argv) {
       
       // Set our VerseKey
       *key = argv[3];
-      mod.SetKey(*key);
+	 mod.setKey(*key);
       FILE *infile;
       // case: add from text file
       //Open our data file and read its contents into the buffer
@@ -68,7 +67,7 @@ int main(int argc, char **argv) {
       else infile = stdin;
       
       entrysize = fread(buffer, sizeof(char), sizeof(buffer), infile);
-      mod.setentry(buffer, entrysize);	// save text to module at current position
+      mod.setEntry(buffer, entrysize);	// save text to module at current position
     }
     else if (compress) {
       char buffer[1048576];  //this is the max size of any entry
@@ -78,7 +77,7 @@ int main(int argc, char **argv) {
       
       // Set our VerseKey
       *key = argv[3];
-      mod.SetKey(*key);
+	 mod.setKey(*key);
       FILE *infile;
       // case: add from text file
       //Open our data file and read its contents into the buffer
@@ -87,7 +86,7 @@ int main(int argc, char **argv) {
       else infile = stdin;
       
       entrysize = fread(buffer, sizeof(char), sizeof(buffer), infile);
-      mod.setentry(buffer, entrysize);	// save text to module at current position
+      mod.setEntry(buffer, entrysize);	// save text to module at current position
     }
     else {
       char buffer[65536];  //this is the max size of any entry
@@ -97,7 +96,7 @@ int main(int argc, char **argv) {
       
       // Set our VerseKey
       *key = argv[3];
-      mod.SetKey(*key);
+	 mod.setKey(*key);
       FILE *infile;
       // case: add from text file
       //Open our data file and read its contents into the buffer
@@ -106,7 +105,7 @@ int main(int argc, char **argv) {
       else infile = stdin;
       
       entrysize = fread(buffer, sizeof(char), sizeof(buffer), infile);
-      mod.setentry(buffer, entrysize);	// save text to module at current position
+      mod.setEntry(buffer, entrysize);	// save text to module at current position
     }
     
   }
@@ -119,7 +118,7 @@ int main(int argc, char **argv) {
       key->Persist(1);      // the magical setting
       
       *key = argv[3];
-      mod.SetKey(*key);
+	 mod.setKey(*key);
       SWKey tmpkey = argv[4];
       mod << &(tmpkey);
     }
@@ -129,7 +128,7 @@ int main(int argc, char **argv) {
       key->Persist(1);      // the magical setting
       
       *key = argv[3];
-      mod.SetKey(*key);
+	 mod.setKey(*key);
       
       SWKey tmpkey = argv[4];
       mod << &(tmpkey);
@@ -140,7 +139,7 @@ int main(int argc, char **argv) {
       key->Persist(1);      // the magical setting
       
       *key = argv[3];
-      mod.SetKey(*key);
+	 mod.setKey(*key);
       
       SWKey tmpkey = argv[4];
       mod << &(tmpkey);
@@ -149,17 +148,17 @@ int main(int argc, char **argv) {
   else if ((mode == 'd') && argc == 4) {
     if (fourbyte) {
       RawLD4 mod(argv[2]);	// open our datapath with our RawText driver.
-      mod.SetKey(argv[3]);
+	 mod.setKey(argv[3]);
       mod.deleteEntry();
     }
     if (compress) {
       zLD mod(argv[2]);	// open our datapath with our RawText driver.
-      mod.SetKey(argv[3]);
+	 mod.setKey(argv[3]);
       mod.deleteEntry();
     }
     else {
       RawLD mod(argv[2]);	// open our datapath with our RawText driver.
-      mod.SetKey(argv[3]);
+      mod.setKey(argv[3]);
       mod.deleteEntry();
     }
     
