@@ -19,11 +19,12 @@
 #include <zipcomprs.h>
 #include <versekey.h>
 #include <stdio.h>
+#include <cipherfil.h>
 
 void errorOutHelp(char *appName) {
 	cerr << appName << " - a tool to create compressed Sword modules\n";
 	cerr << "version 0.1\n\n";
-	cerr << "usage: "<< appName << " <modname> <datapath> [blockType [compressType]]\n\n";
+	cerr << "usage: "<< appName << " <modname> <datapath> [blockType [compressType [cipherKey]]]\n\n";
 	cerr << "datapath: the directory in which to write the zModule\n";
 	cerr << "blockType  : (default 4)\n\t2 - verses\n\t3 - chapters\n\t4 - books\n";
 	cerr << "compressType: (default 1):\n\t1 - LZSS\n\t2 - Zip\n";
@@ -36,12 +37,13 @@ int main(int argc, char **argv)
 {
 	int iType = 4;
 	int compType = 1;
+	string cipherKey = "";
 	SWCompress *compressor = 0;
 	SWModule *inModule     = 0;
 	SWModule *outModule    = 0;
 	
 
-	if ((argc < 3) || (argc > 5)) {
+	if ((argc < 3) || (argc > 6)) {
 		errorOutHelp(argv[0]);
 	}
 
@@ -49,6 +51,9 @@ int main(int argc, char **argv)
 		iType = atoi(argv[3]);
 		if (argc > 4) {
 			compType = atoi(argv[4]);
+			if (argc > 5) {
+				cipherKey = argv[5];
+			}
 		}
 	}
 
@@ -115,8 +120,22 @@ int main(int argc, char **argv)
 		break;
 	}
 
+	if (!cipherKey.empty()) {
+		SWFilter *cipherFilter = new CipherFilter(cipherKey.c_str());
+		outModule->AddRawFilter(cipherFilter);
+	}
+
 	string lastBuffer = "Something that would never be first module entry";
 	SWKey bufferKey;
+	SWKey lastBufferKey;
+	SWKey *outModuleKey = outModule->CreateKey();
+	VerseKey *vkey = SWDYNAMIC_CAST(VerseKey, outModuleKey);
+	outModuleKey->Persist(1);
+	if (vkey) {
+		vkey->Headings(1);
+		vkey->AutoNormalize(0);
+	}
+	outModule->setKey(*outModuleKey);
 
 	inModule->setSkipConsecutiveLinks(false);
 	(*inModule) = TOP;
@@ -124,14 +143,18 @@ int main(int argc, char **argv)
 		bufferKey = *(SWKey *)(*inModule);
 		// pseudo-check for link.  Will get most common links.
 		if ((lastBuffer == inModule->getRawEntry()) &&(lastBuffer.length() > 0)) {
-			(*outModule) << &bufferKey;	// link to last key
-		cout << "Adding [" << bufferKey << "] link to: \n";
+			*outModuleKey = bufferKey;
+			outModule->linkEntry(&lastBufferKey);	// link to last key
+		cout << "Adding [" << bufferKey << "] link to: [" << lastBufferKey << "]\n";
 		}
 		else {
 			lastBuffer = inModule->getRawEntry();
+			lastBufferKey = inModule->KeyText();
 			if (lastBuffer.length() > 0) {
 				cout << "Adding [" << bufferKey << "] new text. \n";
-				outModule->SetKey(bufferKey);
+				*outModuleKey = bufferKey;
+//				outModule->getRawEntry();	// snap
+//				outModule->setKey(bufferKey);
 				(*outModule) << lastBuffer.c_str();	// save new text;
 			}
 			else {
@@ -141,5 +164,6 @@ int main(int argc, char **argv)
 		(*inModule)++;
 	}
 	delete outModule;
+	delete outModuleKey;
 }
 
